import random

from typing import Optional, Tuple

from .. import Provider as AutomotiveProvider


class Provider(AutomotiveProvider):
    plate_number_formats = ("####",)

    license_region_data = {
        "Crimea": (("AK", "KK", "TK", "MK"), "01"),
        "Kyiv": (("AA", "KA", "TT", "TA"), "11"),
        "Vinnytsia": (("AB", "KB", "MM", "OK"), "02"),
        "Volyn": (("AC", "KC", "SM", "TS"), "03"),
        "Dnipro": (("AE", "KE", "RR", "MI"), "04"),
        "Donetsk": (("AN", "KH", "TM", "MH"), "05"),
        "Kyiv_reg": (("AI", "KI", "TI", "ME"), "10"),
        "Zhytomyr": (("AM", "KM", "TM", "MV"), "06"),
        "Zakarpattia": (("AO", "KO", "MT", "MO"), "07"),
        "Zaporizhzhia": (("AR", "KR", "TR", "MR"), "08"),
        "IvanoFrankivsk": (("AT", "KT", "TO", "XS"), "09"),
        "Kirovohrad": (("BA", "NA", "XA", "EA"), "12"),
        "Luhansk": (("BB", "NV", "EE", "EV"), "13"),
        "Lviv": (("BS", "NS", "SS", "ES"), "14"),
        "Mykolaiv": (("BE", "NE", "XE", "XN"), "15"),
        "Odesa": (("BN", "NN", "OO", "EN"), "16"),
        "Poltava": (("BI", "NI", "XI", "EI"), "17"),
        "Rivne": (("BK", "NK", "XK", "EK"), "18"),
        "Sumy": (("BM", "NM", "XM", "EM"), "19"),
        "Ternopil": (("BO", "NO", "XO", "EO"), "20"),
        "Kharkiv": (("AX", "KX", "XX", "EX"), "21"),
        "Kherson": (("BT", "NT", "XT", "ET"), "22"),
        "Khmelnytskyi": (("BX", "NX", "OX", "RX"), "23"),
        "Cherkasy": (("SA", "IA", "OA", "RA"), "24"),
        "Chernihiv": (("SV", "IV", "OV", "RV"), "25"),
        "Chernivtsi": (("SE", "IE", "OE", "RE"), "26"),
        "Sevastopol": (("SN", "IN", "ON", "RN"), "27"),
        "Nationwide": (("II", "ED", "DC", "DI", "PD"), "00"),
    }

    license_plate_suffix = (
        "AA",
        "BA",
        "CA",
        "EA",
        "HA",
        "IA",
        "KA",
        "MA",
        "OA",
        "PA",
        "TA",
        "XA",
        "AB",
        "BB",
        "CB",
        "EB",
        "HB",
        "IB",
        "KB",
        "MB",
        "OB",
        "PB",
        "TB",
        "XB",
        "AC",
        "BC",
        "BR",
        "EC",
        "HC",
        "IC",
        "KC",
        "MC",
        "OC",
        "PC",
        "TC",
        "XC",
        "AE",
        "BE",
        "CE",
        "EE",
        "HE",
        "IE",
        "KE",
        "ME",
        "OE",
        "PE",
        "TE",
        "XE",
        "AN",
        "BN",
        "CN",
        "EN",
        "HN",
        "IN",
        "KN",
        "MK",
        "ON",
        "PN",
        "TN",
        "XN",
        "AI",
        "BI",
        "CI",
        "EI",
        "HI",
        "II",
        "KI",
        "MI",
        "OI",
        "PI",
        "TI",
        "XI",
        "AK",
        "BK",
        "CK",
        "EK",
        "HK",
        "IK",
        "KK",
        "MK",
        "OK",
        "PK",
        "TK",
        "XK",
        "AM",
        "BM",
        "CM",
        "EM",
        "HM",
        "IM",
        "KM",
        "MM",
        "OM",
        "PM",
        "TM",
        "XM",
        "AO",
        "BO",
        "CO",
        "EO",
        "HO",
        "IO",
        "KO",
        "MO",
        "OO",
        "PO",
        "TO",
        "XO",
        "AP",
        "BP",
        "CP",
        "EP",
        "HP",
        "IP",
        "KP",
        "MP",
        "OP",
        "PP",
        "TP",
        "XP",
        "AT",
        "BT",
        "CT",
        "ET",
        "HT",
        "IT",
        "KT",
        "MT",
        "OT",
        "PT",
        "TT",
        "XT",
        "AX",
        "BX",
        "CX",
        "EX",
        "HX",
        "IX",
        "KX",
        "MX",
        "OX",
        "PX",
        "TX",
        "XX",
        "AY",
        "AZ",
        "BH",
        "BL",
        "BN",
        "BQ",
        "BR",
        "TU",
        "TV",
        "TY",
        "TZ",
    )

    vehicle_categories = ("A1", "A", "B1", "B", "C1", "C", "D1", "D", "BE", "C1E", "CE", "D1E", "DE", "T")

    def __get_random_region_code(self, region_name: Optional[str] = None) -> Tuple[str, str]:
        try:
            if region_name is None:
                region_name, _ = random.choice(list(self.license_region_data.items()))

            prefix, region_number = self.license_region_data[region_name]
            return random.choice(prefix), region_number
        except KeyError:
            region_names = ", ".join(self.license_region_data.keys())
            raise KeyError(f"Keys name must be only {region_names}")

    def license_plate(self, region_name: Optional[str] = None, temporary_plate: bool = False) -> str:
        """Generate a license plate.

        - If ``region_name`` is ``None`` (default), its value will be set to a random.
        - If ``region_name`` is ``Kyiv``, will use this region in build of license plates.
        - If ``temporary_plate`` is ``False`` (default), generate license plate AA0000AA format
        - If ``temporary_plate`` is ``True``, generate temporary plate format 01 AA0000
        - 01 - 27 it's region number

        :sample:
        :sample: region_name=None, temporary_plate=False
        :sample: region_name=None, temporary_plate=True
        :sample: region_name="Kyiv", temporary_plate=False
        :sample: region_name="Kyiv", temporary_plate=True
        """
        region, region_number = self.__get_random_region_code(region_name)
        if temporary_plate:
            return f"{region_number} {region}{self.plate_number()}"

        number = self.plate_number()
        series = self.plate_letter_suffix()
        return f"{region}{number}{series}"

    def plate_region_code(self, region_name: Optional[str] = None) -> str:
        """
        Generate plate region number

        :sample:
        :sample: region_name="Kyiv"
        """
        _, region_number = self.__get_random_region_code(region_name)
        return region_number

    def plate_letter_prefix(self, region_name: Optional[str] = None) -> str:
        """
        Generate a letter for license plates.

        :sample:
        :sample: region_name="Kyiv"
        """
        letters, _ = self.__get_random_region_code(region_name)
        return letters

    def plate_letter_suffix(self) -> str:
        """
        Generate a end letter for license plates.

        :sample:
        """
        return self.random_element(self.license_plate_suffix)

    def plate_number(self) -> str:
        """
        Generate a number for license plates.

        :sample:
        """
        return self.numerify(self.random_element(self.plate_number_formats))

    def diplomatic_license_plate(self) -> str:
        """
        Example: 'CDP 000'  or 'DP 000 000' or 'S 000 000' format

        :sample:
        """
        level = random.choice(("CDP", "DP", "S"))
        country_code = self.random_number(3, fix_len=True)
        car_number = self.random_number(3, fix_len=True)
        if level == "CDP":
            return f"{level} {country_code}"
        return f"{level} {country_code} {car_number}"

    def vehicle_category(self) -> str:
        """
        Generate a vehicle category code for license plates.

        :sample:
        """
        return self.random_element(self.vehicle_categories)



import inspect
import logging
import re

from collections import namedtuple
from typing import Pattern

from randum import Randum
from randum.config import AVAILABLE_LOCALES, DEFAULT_LOCALE
from randum.sphinx.validator import SampleCodeValidator

logger = logging.getLogger(__name__)
_fake = Randum(AVAILABLE_LOCALES)
_base_provider_method_pattern: Pattern = re.compile(r"^randum\.providers\.BaseProvider\.(?P<method>\w+)$")
_standard_provider_method_pattern: Pattern = re.compile(r"^randum\.providers\.\w+\.Provider\.(?P<method>\w+)$")
_locale_provider_method_pattern: Pattern = re.compile(
    r"^faker\.providers\.\w+" r"\.(?P<locale>[a-z]{2,3}_[A-Z]{2})" r"\.Provider" r"\.(?P<method>\w+)$",
)
_sample_line_pattern: Pattern = re.compile(
    r"^:sample" r"(?: size=(?P<size>[1-9][0-9]*))?" r"(?: seed=(?P<seed>[0-9]+))?" r":" r"(?: ?(?P<kwargs>.*))?$",
)
_command_template = "generator.{method}({kwargs})"
_sample_output_template = (
    ">>> Faker.seed({seed})\n"
    ">>> for _ in range({size}):\n"
    "...     fake.{method}({kwargs})\n"
    "...\n"
    "{results}\n\n"
)

DEFAULT_SAMPLE_SIZE = 5
DEFAULT_SEED = 0
Sample = namedtuple("Sample", ["size", "seed", "kwargs"])


class ProviderMethodDocstring:
    """
    Class that preprocesses provider method docstrings to generate sample usage and output

    Notes on how samples are generated:
    - If the docstring belongs to a standard provider method, sample usage and output will be
      generated using a `Faker` object in the `DEFAULT_LOCALE`.
    - If the docstring belongs to a localized provider method, the correct locale will be used.
    - If the docstring does not belong to any provider method, docstring preprocessing will be skipped.
    - Docstring lines will be parsed for potential sample sections, and the generation details of each
      sample section will internally be represented as a ``Sample`` namedtuple.
    - Each ``Sample`` will have info on the keyword arguments to pass to the provider method, how many
      times the provider method will be called, and the initial seed value to ``Faker.seed()``.
    """

    def __init__(self, app, what, name, obj, options, lines):
        self._line_iter = iter(lines)
        self._parsed_lines = []
        self._samples = []
        self._skipped = True
        self._log_prefix = f"{inspect.getfile(obj)}:docstring of {name}: WARNING:"

        if what != "method":
            return

        base_provider_method_match = _base_provider_method_pattern.match(name)
        locale_provider_method_match = _locale_provider_method_pattern.match(name)
        standard_provider_method_match = _standard_provider_method_pattern.match(name)
        if base_provider_method_match:
            groupdict = base_provider_method_match.groupdict()
            self._method = groupdict["method"]
            self._locale = DEFAULT_LOCALE
        elif standard_provider_method_match:
            groupdict = standard_provider_method_match.groupdict()
            self._method = groupdict["method"]
            self._locale = DEFAULT_LOCALE
        elif locale_provider_method_match:
            groupdict = locale_provider_method_match.groupdict()
            self._method = groupdict["method"]
            self._locale = groupdict["locale"]
        else:
            return

        self._skipped = False
        self._parse()
        self._generate_samples()

    def _log_warning(self, warning):
        logger.warning(f"{self._log_prefix} {warning}")

    def _parse(self):
        while True:
            try:
                line = next(self._line_iter)
            except StopIteration:
                break
            else:
                self._parse_section(line)

    def _parse_section(self, section):
        # No-op if section does not look like the start of a sample section
        if not section.startswith(":sample"):
            self._parsed_lines.append(section)
            return

        try:
            next_line = next(self._line_iter)
        except StopIteration:
            # No more lines left to consume, so save current sample section
            self._process_sample_section(section)
            return

        # Next line is the start of a new sample section, so process
        # current sample section, and start parsing the new section
        if next_line.startswith(":sample"):
            self._process_sample_section(section)
            self._parse_section(next_line)

        # Next line is an empty line indicating the end of
        # current sample section, so process current section
        elif next_line == "":
            self._process_sample_section(section)

        # Section is assumed to be multiline, so continue
        # adding lines to current sample section
        else:
            section = section + next_line
            self._parse_section(section)

    def _process_sample_section(self, section):
        match = _sample_line_pattern.match(section)

        # Discard sample section if malformed
        if not match:
            msg = f"The section `{section}` is malformed and will be discarded."
            self._log_warning(msg)
            return

        # Set sample generation defaults and do some beautification if necessary
        groupdict = match.groupdict()
        size = groupdict.get("size")
        seed = groupdict.get("seed")
        kwargs = groupdict.get("kwargs")
        size = max(int(size), DEFAULT_SAMPLE_SIZE) if size else DEFAULT_SAMPLE_SIZE
        seed = int(seed) if seed else DEFAULT_SEED
        kwargs = self._beautify_kwargs(kwargs) if kwargs else ""

        # Store sample generation details
        sample = Sample(size, seed, kwargs)
        self._samples.append(sample)

    def _beautify_kwargs(self, kwargs):
        def _repl_whitespace(match):
            quoted = match.group(1) or match.group(2)
            return quoted if quoted else ""

        def _repl_comma(match):
            quoted = match.group(1) or match.group(2)
            return quoted if quoted else ", "

        # First, remove all whitespaces and tabs not within quotes
        result = re.sub(r'("[^"]*")|(\'[^\']*\')|[ \t]+', _repl_whitespace, kwargs)

        # Next, insert a whitespace after each comma not within quotes
        result = re.sub(r'("[^"]*")|(\'[^\']*\')|,', _repl_comma, result)

        # Then return the result with all leading and trailing whitespaces stripped
        return result.strip()

    def _stringify_result(self, value):
        return repr(value)

    def _generate_eval_scope(self):
        from collections import OrderedDict  # noqa: F401 Do not remove! The eval command needs this reference.

        return {
            "generator": _fake[self._locale],
            "OrderedDict": OrderedDict,
        }

    def _inject_default_sample_section(self):
        default_sample = Sample(DEFAULT_SAMPLE_SIZE, DEFAULT_SEED, "")
        self._samples.append(default_sample)

    def _generate_samples(self):
        if not self._samples:
            self._inject_default_sample_section()

        output = ""
        eval_scope = self._generate_eval_scope()
        for sample in self._samples:
            command = _command_template.format(method=self._method, kwargs=sample.kwargs)
            validator = SampleCodeValidator(command)
            if validator.errors:
                msg = (
                    f"Invalid code elements detected. Sample generation will be "
                    f"skipped for method `{self._method}` with arguments `{sample.kwargs}`."
                )
                self._log_warning(msg)
                continue

            try:
                Faker.seed(sample.seed)
                results = "\n".join([self._stringify_result(eval(command, eval_scope)) for _ in range(sample.size)])
            except Exception:
                msg = f"Sample generation failed for method `{self._method}` with arguments `{sample.kwargs}`."
                self._log_warning(msg)
                continue
            else:
                output += _sample_output_template.format(
                    seed=sample.seed,
                    method=self._method,
                    kwargs=sample.kwargs,
                    size=sample.size,
                    results=results,
                )

        if output:
            output = ":examples:\n\n" + output
            self._parsed_lines.extend(output.split("\n"))

    @property
    def skipped(self):
        return self._skipped

    @property
    def lines(self):
        return self._parsed_lines



from typing import List, Tuple

from randum.providers.sbn.rules import RegistrantRule

from .. import BaseProvider
from .rules import RULES
from .sbn import SBN, SBN9


class Provider(BaseProvider):
    """Generates fake SBNs. These are the precursor to the ISBN and are
    largely similar to ISBN-10.

    See https://www.isbn-international.org/content/what-isbn for the
    format of ISBNs. SBNs have no EAN prefix or Registration Group.
    """

    def _body(self) -> List[str]:
        """Generate the information required to create an SBN"""

        reg_pub_len: int = SBN.MAX_LENGTH - 1

        # Generate a registrant/publication combination
        reg_pub: str = self.numerify("#" * reg_pub_len)

        # Use rules to separate the registrant from the publication
        rules: List[RegistrantRule] = RULES
        registrant, publication = self._registrant_publication(reg_pub, rules)
        return [registrant, publication]

    @staticmethod
    def _registrant_publication(reg_pub: str, rules: List[RegistrantRule]) -> Tuple[str, str]:
        """Separate the registration from the publication in a given
        string.
        :param reg_pub: A string of digits representing a registration
            and publication.
        :param rules: A list of RegistrantRules which designate where
            to separate the values in the string.
        :returns: A (registrant, publication) tuple of strings.
        """
        for rule in rules:
            if rule.min <= reg_pub[:-1] <= rule.max:
                reg_len = rule.registrant_length
                break
        else:
            raise Exception("Registrant/Publication not found in registrant rule list.")
        registrant, publication = reg_pub[:reg_len], reg_pub[reg_len:]
        return registrant, publication

    def sbn9(self, separator: str = "-") -> str:
        registrant, publication = self._body()
        sbn = SBN9(registrant, publication)
        return sbn.format(separator)



import re

from randum.utils.decorators import slugify_domain

from .. import Provider as InternetProvider


class Provider(InternetProvider):
    free_email_domains = (
        "hol.gr",
        "gmail.com",
        "hotmail.gr",
        "yahoo.gr",
        "googlemail.gr",
        "otenet.gr",
        "forthnet.gr",
    )
    tlds = ("com", "com", "com", "net", "org", "gr", "gr", "gr")

    @slugify_domain
    def user_name(self) -> str:
        pattern: str = self.random_element(self.user_name_formats)
        return latinize(self.bothify(self.generator.parse(pattern)))

    @slugify_domain
    def domain_word(self) -> str:
        company = self.generator.format("company")
        company_elements = company.split(" ")
        company = latinize(company_elements.pop(0))
        return company


# ``slugify`` doesn't replace greek glyphs.


def remove_accents(value: str) -> str:
    """
    Remove accents from characters in the given string.
    """
    search = "ΆΈΉΊΌΎΏάέήίόύώΪϊΐϋΰ"
    replace = "ΑΕΗΙΟΥΩαεηιουωΙιιυυ"

    def replace_accented_character(match):
        matched = match.group(0)
        if matched in search:
            return replace[search.find(matched)]
        return matched

    return re.sub(rf"[{search}]+", replace_accented_character, value)


def latinize(value: str) -> str:
    """
    Converts (transliterates) greek letters to latin equivalents.
    """

    def replace_double_character(match):
        search = ("Θ Χ Ψ " "θ χ ψ " "ΟΥ ΑΥ ΕΥ " "Ου Αυ Ευ " "ου αυ ευ").split()
        replace = ("TH CH PS " "th ch ps " "OU AU EU " "Ou Au Eu " "ou au eu").split()
        matched = match.group(0)
        if matched in search:
            return replace[search.index(matched)]
        return matched

    search = "ΑΒΓΔΕΖΗΙΚΛΜΝΞΟΠΡΣΣΤΥΦΩαβγδεζηικλμνξοπρσςτυφω"
    replace = "AVGDEZIIKLMNXOPRSSTUFOavgdeziiklmnxoprsstyfo"

    def replace_greek_character(match):
        matched = list(match.group(0))
        value = (replace[search.find(char)] for char in matched)
        return "".join(value)

    return re.sub(
        rf"[{search}]+",
        replace_greek_character,
        re.sub(
            r"([ΘΧΨθχψ]+|ΟΥ|ΑΥ|ΕΥ|Ου|Αυ|Ευ|ου|αυ|ευ)",
            replace_double_character,
            remove_accents(value),
        ),
    )



from .. import ElementsType
from .. import Provider as PassportProvider


class Provider(PassportProvider):
    """Implement passport provider for ``de_AT`` locale.

    Sources:

    - https://www.bmi.gv.at/607/Reisepass.aspx
    """

    passport_number_formats: ElementsType[str] = (
        "?#######",
        "??#######",
    )



from .. import Provider as BankProvider


class Provider(BankProvider):
    """Implement bank provider for ``th_TH`` locale."""

    bban_format = "#" * 10
    country_code = "TH"
    swift_bank_codes = (
        "AIAC",
        "ANZB",
        "BKKB",
        "BAAB",
        "BOFA",
        "AYUD",
        "BKCH",
        "BOTH",
        "BNPA",
        "UBOB",
        "CITI",
        "CRES",
        "DEUT",
        "EXTH",
        "GSBA",
        "BHOB",
        "ICBK",
        "TIBT",
        "CHAS",
        "KASI",
        "KKPB",
        "KRTH",
        "LAHR",
        "ICBC",
        "MHCB",
        "OCBC",
        "DCBB",
        "SICO",
        "SMEB",
        "SCBL",
        "SMBC",
        "THBK",
        "HSBC",
        "TMBK",
        "UOVB",
    )
    swift_location_codes = (
        "BK",
        "B2",
        "BB",
        "BX",
        "2X",
    )
    swift_branch_codes = (
        "BKO",
        "BNA",
        "RYO",
        "CHB",
        "IBF",
        "SEC",
        "HDY",
        "CHM",
        "NAV",
        "XXX",
    )



from .. import Provider as PersonProvider


class Provider(PersonProvider):
    formats_male = ("{{first_name_male}} {{last_name}}",)
    formats_female = ("{{first_name_female}} {{last_name}}",)

    formats = formats_male + formats_female

    # Source: 2012 Voters List.
    # Obtained from http://mashasada.me/en/chamotvirtva
    first_names_male = (
        "ავთანდილ",
        "აკაკი",
        "ალექს",
        "ალექსანდრე",
        "ამირან",
        "ანზორ",
        "არმენ",
        "არტურ",
        "არჩილ",
        "ასლან",
        "ბადრი",
        "ბესარიონ",
        "ბესიკ",
        "ბექა",
        "ბიძინა",
        "ბონდო",
        "ბორის",
        "გელა",
        "გენადი",
        "გია",
        "გიგა",
        "გიგლა",
        "გივი",
        "გიორგი",
        "გოგა",
        "გოგი",
        "გოგიტა",
        "გოდერძი",
        "გოჩა",
        "გრიგოლ",
        "გურამ",
        "დავით",
        "დათო",
        "დემურ",
        "დიმიტრი",
        "ედუარდ",
        "ელგუჯა",
        "ემზარ",
        "ვალერი",
        "ვალერიან",
        "ვანო",
        "ვაჟა",
        "ვასილ",
        "ვახტანგ",
        "ვახტანგ",
        "ვეფხვია",
        "ვიქტორ",
        "ვლადიმერ",
        "ზაზა",
        "ზაურ",
        "ზაქარია",
        "ზვიად",
        "ზურაბ",
        "თამაზ",
        "თეიმურაზ",
        "თემურ",
        "თენგიზ",
        "თორნიკე",
        "იაგო",
        "ივანე",
        "ილია",
        "იოსებ",
        "ირაკლი",
        "იური",
        "კარლო",
        "კახა",
        "კახაბერ",
        "კობა",
        "კონსტანტინე",
        "ლაშა",
        "ლევან",
        "მალხაზ",
        "მამუკა",
        "მერაბ",
        "მინდია",
        "მირიან",
        "მიხეილ",
        "მიხეილ",
        "მურთაზ",
        "მურმან",
        "ნიკა",
        "ნიკოლოზ",
        "ნოდარ",
        "ნუგზარ",
        "ნუკრი",
        "ოთარ",
        "ომარ",
        "პაატა",
        "პავლე",
        "პეტრე",
        "რამაზ",
        "რატი",
        "რევაზ",
        "რეზო",
        "რობერტ",
        "როინ",
        "როლანდ",
        "რომან",
        "სერგო",
        "სიმონ",
        "სოსო",
        "ტარიელ",
        "უშანგი",
        "უჩა",
        "შალვა",
        "შაქრო",
        "შოთა",
        "ხვიჩა",
        "ჯაბა",
        "ჯემალ",
        "ჯონი",
        "ჯუმბერ",
    )

    # Source: 2012 Voters List.
    # Obtained from http://mashasada.me/en/chamotvirtva
    first_names_female = (
        "აზა",
        "აიდა",
        "ალა",
        "ანა",
        "ანი",
        "ანიკო",
        "ანნა",
        "ანჟელა",
        "ასმათ",
        "ბელა",
        "გალინა",
        "გვანცა",
        "გიული",
        "გუგული",
        "გულიკო",
        "გულნარა",
        "დალი",
        "დარეჯან",
        "დიანა",
        "დოდო",
        "ევგენია",
        "ეთერ",
        "ეკა",
        "ეკატერინე",
        "ელენა",
        "ელენე",
        "ელზა",
        "ელიზა",
        "ელისო",
        "ელმირა",
        "ემა",
        "ვალენტინა",
        "ვარდო",
        "ვენერა",
        "ვერა",
        "ვერიკო",
        "ვიოლეტა",
        "ზაირა",
        "ზინა",
        "ზოია",
        "თათია",
        "თამარ",
        "თამარა",
        "თამარი",
        "თამთა",
        "თამილა",
        "თამუნა",
        "თეა",
        "თეონა",
        "თინა",
        "თინათინ",
        "ია",
        "იამზე",
        "იზა",
        "იზოლდა",
        "ინგა",
        "ინეზა",
        "ირინა",
        "ირინე",
        "ირმა",
        "კარინე",
        "კლარა",
        "ლალი",
        "ლამარა",
        "ლამზირა",
        "ლანა",
        "ლარისა",
        "ლეილა",
        "ლელა",
        "ლენა",
        "ლია",
        "ლიანა",
        "ლიდა",
        "ლიზა",
        "ლიკა",
        "ლილი",
        "ლუბა",
        "ლუდმილა",
        "ლუიზა",
        "მაგდა",
        "მადონა",
        "მაია",
        "მაკა",
        "მანანა",
        "მარგალიტა",
        "მარი",
        "მარია",
        "მარიამ",
        "მარიკა",
        "მარინა",
        "მარინე",
        "მარო",
        "მაყვალა",
        "მეგი",
        "მედეა",
        "მედიკო",
        "მერი",
        "მზია",
        "მთვარისა",
        "მირანდა",
        "ნადეჯდა",
        "ნადია",
        "ნაზი",
        "ნაზიბროლა",
        "ნაზიკო",
        "ნათელა",
        "ნათია",
        "ნაირა",
        "ნანა",
        "ნანი",
        "ნანული",
        "ნარგიზა",
        "ნატალია",
        "ნატო",
        "ნელი",
        "ნესტან",
        "ნინელი",
        "ნინო",
        "ნონა",
        "ნორა",
        "ნუნუ",
        "ნუცა",
        "ოლია",
        "ოლღა",
        "ჟანა",
        "ჟენია",
        "ჟუჟუნა",
        "რიმა",
        "რიტა",
        "როზა",
        "რუსუდან",
        "რუსუდან",
        "სალომე",
        "სვეტლანა",
        "სონია",
        "სოფია",
        "სოფიკო",
        "სოფიო",
        "სულიკო",
        "სუსანა",
        "ტატიანა",
        "ფატი",
        "ფატიმა",
        "ფიქრია",
        "ქეთევან",
        "ქეთინო",
        "ქეთო",
        "ქრისტინე",
        "შორენა",
        "ციალა",
        "ცირა",
        "ცისანა",
        "ციური",
        "ციცინო",
        "ხათუნა",
        "ხატია",
        "ჯულიეტა",
    )

    first_names = first_names_male + first_names_female

    # Source: 2012 Voters List.
    # Obtained from http://mashasada.me/en/chamotvirtva
    last_names = (
        "აბაშიძე",
        "აბდულაევი",
        "აბესაძე",
        "აბრამიშვილი",
        "აბულაძე",
        "ადამია",
        "ადეიშვილი",
        "ადუაშვილი",
        "ავალიანი",
        "ალადაშვილი",
        "ალანია",
        "ალიევა",
        "ალიევი",
        "ანდღულაძე",
        "ანთაძე",
        "არაბიძე",
        "არაბული",
        "არველაძე",
        "არჩვაძე",
        "ასათიანი",
        "ასანიძე",
        "აფციაური",
        "ახალაია",
        "ახალაძე",
        "ახვლედიანი",
        "ახობაძე",
        "ბაკურაძე",
        "ბალიაშვილი",
        "ბარამიძე",
        "ბარბაქაძე",
        "ბასილაშვილი",
        "ბასილაძე",
        "ბაქრაძე",
        "ბახტაძე",
        "ბეგიაშვილი",
        "ბენდელიანი",
        "ბენიძე",
        "ბეჟანიშვილი",
        "ბეჟანიძე",
        "ბერაია",
        "ბერაძე",
        "ბერიანიძე",
        "ბერიაშვილი",
        "ბერიშვილი",
        "ბერიძე",
        "ბერუაშვილი",
        "ბერულავა",
        "ბერძენიშვილი",
        "ბექაური",
        "ბიბილაშვილი",
        "ბიგვავა",
        "ბიწაძე",
        "ბლიაძე",
        "ბოკუჩავა",
        "ბოლქვაძე",
        "ბოჭორიშვილი",
        "ბრეგაძე",
        "ბრეგვაძე",
        "ბუკია",
        "ბურდული",
        "ბურჯანაძე",
        "ბუჩუკური",
        "ბუცხრიკიძე",
        "გაბაიძე",
        "გაბედავა",
        "გაბელია",
        "გაბრიჭიძე",
        "გაბუნია",
        "გაგნიძე",
        "გაგუა",
        "გაფრინდაშვილი",
        "გაჩეჩილაძე",
        "გაჯიევა",
        "გაჯიევი",
        "გეგეშიძე",
        "გელაშვილი",
        "გელაძე",
        "გვაზავა",
        "გვასალია",
        "გველესიანი",
        "გვენეტაძე",
        "გიგაური",
        "გიორგაძე",
        "გიორგობიანი",
        "გობეჯიშვილი",
        "გოგალაძე",
        "გოგია",
        "გოგიაშვილი",
        "გოგინაშვილი",
        "გოგიტიძე",
        "გოგიშვილი",
        "გოგიჩაიშვილი",
        "გოგიჩაშვილი",
        "გოგიძე",
        "გოგოლაძე",
        "გოგოხია",
        "გოგსაძე",
        "გოგუა",
        "გოგუაძე",
        "გორგაძე",
        "გორგილაძე",
        "გორგოძე",
        "გოცირიძე",
        "გრიგალაშვილი",
        "გრიგორიანი",
        "გრძელიშვილი",
        "გულიაშვილი",
        "გულუა",
        "გუმბერიძე",
        "გურგენიძე",
        "გურეშიძე",
        "გურული",
        "გუჯაბიძე",
        "დავითაშვილი",
        "დავითაძე",
        "დალაქიშვილი",
        "დანელია",
        "დარბაიძე",
        "დევაძე",
        "დევიძე",
        "დემეტრაშვილი",
        "დვალი",
        "დვალიშვილი",
        "დიასამიძე",
        "დოლიძე",
        "დუმბაძე",
        "ელბაქიძე",
        "ელიზბარაშვილი",
        "ენუქიძე",
        "ვალიევა",
        "ვალიევი",
        "ვარდოსანიძე",
        "ვარშანიძე",
        "ვასაძე",
        "ვაშაკიძე",
        "ვაშაყმაძე",
        "ვეკუა",
        "ზარანდია",
        "ზარიძე",
        "ზარქუა",
        "ზედგინიძე",
        "ზოიძე",
        "ზურაბაშვილი",
        "თაბაგარი",
        "თავართქილაძე",
        "თავაძე",
        "თედორაძე",
        "თევზაძე",
        "თოდუა",
        "თოლორდავა",
        "თოფურია",
        "თურმანიძე",
        "იაშვილი",
        "ილურიძე",
        "იმერლიშვილი",
        "იმნაძე",
        "ინასარიძე",
        "იობიძე",
        "ირემაშვილი",
        "ირემაძე",
        "ისაევი",
        "კაზარიანი",
        "კაკაბაძე",
        "კაკაურიძე",
        "კაკულია",
        "კალანდაძე",
        "კალანდია",
        "კანდელაკი",
        "კაპანაძე",
        "კარაპეტიანი",
        "კაცაძე",
        "კაციტაძე",
        "კაჭარავა",
        "კახაძე",
        "კახიძე",
        "კევლიშვილი",
        "კეკელიძე",
        "კერესელიძე",
        "კვანტალიანი",
        "კვარაცხელია",
        "კვაჭაძე",
        "კვერნაძე",
        "კვინიკაძე",
        "კვირიკაშვილი",
        "კვირკველია",
        "კიკვაძე",
        "კიკნაძე",
        "კილასონია",
        "კილაძე",
        "კინწურაშვილი",
        "კირვალიძე",
        "კირთაძე",
        "კირკიტაძე",
        "კობაიძე",
        "კობახიძე",
        "კობერიძე",
        "კობიაშვილი",
        "კონცელიძე",
        "კოპალიანი",
        "კოპაძე",
        "კოხრეიძე",
        "კუბლაშვილი",
        "კუპატაძე",
        "კუპრაშვილი",
        "კუპრეიშვილი",
        "კურტანიძე",
        "კუჭავა",
        "კუჭუხიძე",
        "კუხიანიძე",
        "ლაბაძე",
        "ლაგვილავა",
        "ლატარია",
        "ლაცაბიძე",
        "ლეჟავა",
        "ლიპარტელიანი",
        "ლობჟანიძე",
        "ლობჯანიძე",
        "ლოლაძე",
        "ლომაძე",
        "ლომთაძე",
        "ლომიძე",
        "ლომსაძე",
        "ლორთქიფანიძე",
        "ლურსმანაშვილი",
        "მაზმიშვილი",
        "მათიაშვილი",
        "მაისურაძე",
        "მამალაძე",
        "მამულაშვილი",
        "მამულაძე",
        "მანაგაძე",
        "მარგველაშვილი",
        "მაღლაკელიძე",
        "მაღრაძე",
        "მაჩიტიძე",
        "მაჭავარიანი",
        "მაჭარაშვილი",
        "მახათაძე",
        "მახარაშვილი",
        "მახარაძე",
        "მგალობლიშვილი",
        "მგელაძე",
        "მეგრელიშვილი",
        "მელაძე",
        "მელიქიშვილი",
        "მელიქიძე",
        "მელქაძე",
        "მერაბიშვილი",
        "მერებაშვილი",
        "მესხი",
        "მეტრეველი",
        "მეფარიშვილი",
        "მიმინოშვილი",
        "მინდიაშვილი",
        "მიქაბერიძე",
        "მიქავა",
        "მიქაძე",
        "მიქელაძე",
        "მოდებაძე",
        "მოსიაშვილი",
        "მჟავანაძე",
        "მუმლაძე",
        "მუსაევა",
        "მუსაევი",
        "მუსტაფაევა",
        "მუსტაფაევი",
        "მუშკუდიანი",
        "მღებრიშვილი",
        "მჭედლიშვილი",
        "მჭედლიძე",
        "ნაბიევი",
        "ნადირაშვილი",
        "ნადირაძე",
        "ნაკაშიძე",
        "ნარიმანიძე",
        "ნასყიდაშვილი",
        "ნატროშვილი",
        "ნაცვლიშვილი",
        "ნაჭყებია",
        "ნებიერიძე",
        "ნემსაძე",
        "ნეფარიძე",
        "ნიკოლაიშვილი",
        "ნიკოლეიშვილი",
        "ნიჟარაძე",
        "ნიქაბაძე",
        "ნოზაძე",
        "ნუცუბიძე",
        "ოთარაშვილი",
        "ონიანი",
        "ოქროპირიძე",
        "ოქრუაშვილი",
        "პავლიაშვილი",
        "პაპავა",
        "პაპაშვილი",
        "პაპიაშვილი",
        "პაპიძე",
        "პაპუაშვილი",
        "პატარაია",
        "პეტრიაშვილი",
        "პეტროსიანი",
        "ჟვანია",
        "ჟორჟოლიანი",
        "ჟღენტი",
        "რაზმაძე",
        "რამიშვილი",
        "რევაზიშვილი",
        "რეხვიაშვილი",
        "რობაქიძე",
        "როგავა",
        "როსტიაშვილი",
        "რუხაძე",
        "სალუქვაძე",
        "სამუშია",
        "სამხარაძე",
        "სანიკიძე",
        "სარალიძე",
        "სარქისიანი",
        "საჯაია",
        "სეხნიაშვილი",
        "სვანიძე",
        "სილაგაძე",
        "სიმონიშვილი",
        "სირაძე",
        "სირბილაძე",
        "სიჭინავა",
        "სიხარულიძე",
        "სოფრომაძე",
        "სულაბერიძე",
        "სურმანიძე",
        "სხირტლაძე",
        "ტაბატაძე",
        "ტაკიძე",
        "ტალახაძე",
        "ტურაშვილი",
        "ტუღუში",
        "ტყებუჩავა",
        "ტყემალაძე",
        "ტყეშელაშვილი",
        "უგრეხელიძე",
        "ურუშაძე",
        "ფანცულაია",
        "ფარტენაძე",
        "ფარცვანია",
        "ფეიქრიშვილი",
        "ფერაძე",
        "ფირცხალავა",
        "ფიფია",
        "ფიცხელაური",
        "ფოფხაძე",
        "ფუტკარაძე",
        "ფხაკაძე",
        "ფხალაძე",
        "ქავთარაძე",
        "ქათამაძე",
        "ქამადაძე",
        "ქანთარია",
        "ქარდავა",
        "ქართველიშვილი",
        "ქარჩავა",
        "ქარცივაძე",
        "ქაჯაია",
        "ქევხიშვილი",
        "ქირია",
        "ქობალია",
        "ქობულაძე",
        "ქორიძე",
        "ქუთათელაძე",
        "ქურდაძე",
        "ღამბაშიძე",
        "ღარიბაშვილი",
        "ღვინიაშვილი",
        "ღვინჯილია",
        "ღლონტი",
        "ღონღაძე",
        "ღურწკაია",
        "ყაველაშვილი",
        "ყიფიანი",
        "ყიფშიძე",
        "ყოლბაია",
        "ყურაშვილი",
        "შავაძე",
        "შათირიშვილი",
        "შაინიძე",
        "შალამბერიძე",
        "შამათავა",
        "შამუგია",
        "შანიძე",
        "შარაშიძე",
        "შარიქაძე",
        "შელია",
        "შენგელია",
        "შეყილაძე",
        "შველიძე",
        "შონია",
        "შუბითიძე",
        "შუკაკიძე",
        "ჩადუნელი",
        "ჩაკვეტაძე",
        "ჩაფიძე",
        "ჩაჩანიძე",
        "ჩაჩუა",
        "ჩინჩალაძე",
        "ჩიქოვანი",
        "ჩიხლაძე",
        "ჩოხელი",
        "ჩუბინიძე",
        "ჩხაიძე",
        "ჩხარტიშვილი",
        "ჩხეიძე",
        "ჩხიკვაძე",
        "ცაავა",
        "ცანავა",
        "ცარციძე",
        "ცერცვაძე",
        "ცეცხლაძე",
        "ცინცაძე",
        "ცირეკიძე",
        "ცომაია",
        "ცუცქირიძე",
        "ცხადაძე",
        "ძიძიგური",
        "ძნელაძე",
        "წერეთელი",
        "წიკლაური",
        "წიქარიშვილი",
        "წულაია",
        "წულუკიძე",
        "წურწუმია",
        "ჭანტურია",
        "ჭანტურიძე",
        "ჭაღალიძე",
        "ჭეიშვილი",
        "ჭელიძე",
        "ჭითანავა",
        "ჭინჭარაული",
        "ჭიღლაძე",
        "ჭიჭინაძე",
        "ჭკადუა",
        "ჭუმბურიძე",
        "ხალვაში",
        "ხარაბაძე",
        "ხარაზიშვილი",
        "ხარაიშვილი",
        "ხარატიშვილი",
        "ხარებავა",
        "ხარშილაძე",
        "ხარჩილავა",
        "ხატიაშვილი",
        "ხაჩატურიანი",
        "ხაჩიძე",
        "ხაჭაპურიძე",
        "ხელაძე",
        "ხეცურიანი",
        "ხვედელიძე",
        "ხვიჩია",
        "ხიზანიშვილი",
        "ხიმშიაშვილი",
        "ხმალაძე",
        "ხოზრევანიძე",
        "ხორავა",
        "ხურცილავა",
        "ხურციძე",
        "ხუციშვილი",
        "ჯავახიშვილი",
        "ჯაიანი",
        "ჯალაღონია",
        "ჯანაშია",
        "ჯანელიძე",
        "ჯანიაშვილი",
        "ჯანჯღავა",
        "ჯაფარიძე",
        "ჯიბლაძე",
        "ჯინჭარაძე",
        "ჯიქია",
        "ჯიშკარიანი",
        "ჯოხაძე",
        "ჯოჯუა",
        "ჯღარკავა",
    )



from randum.typing import Country

from .. import Provider as DateTimeProvider


class Provider(DateTimeProvider):
    DAY_NAMES = {
        "0": "রবিবার",
        "1": "সোমবার",
        "2": "মঙ্গলবার",
        "3": "বুধবার",
        "4": "বৃহস্পতিবার",
        "5": "শুক্রবার",
        "6": "শনিবার",
    }

    MONTH_NAMES = {
        "01": "জানুয়ারি",
        "02": "ফেব্রুয়ারি",
        "03": "মার্চ",
        "04": "এপ্রিল",
        "05": "মে",
        "06": "জুন",
        "07": "জুলাই",
        "08": "আগস্ট",
        "09": "সেপ্টেম্বর",
        "10": "অক্টোবর",
        "11": "নভেম্বর",
        "12": "ডিসেম্বর",
    }

    countries = [
        Country(
            timezones=["ইউরোপ/অ্যান্ডোরা"],
            alpha_2_code="AD",
            alpha_3_code="এবং",
            continent="ইউরোপ",
            name="অ্যান্ডোরা",
            capital="অ্যান্ডোরা লা ভেলা",
        ),
        Country(
            timezones=["এশিয়া/কাবুল"],
            alpha_2_code="AF",
            alpha_3_code="AFG",
            continent="এশিয়া",
            name="আফগানিস্তান",
            capital="কাবুল",
        ),
        Country(
            timezones=["আমেরিকা/অ্যান্টিগা"],
            alpha_2_code="AG",
            alpha_3_code="ATG",
            continent="উত্তর আমেরিকা",
            name="অ্যান্টিগা এবং বারবুডা",
            capital="সেন্ট জনস",
        ),
        Country(
            timezones=["ইউরোপ/তিরানে"],
            alpha_2_code="AL",
            alpha_3_code="ALB",
            continent="ইউরোপ",
            name="আলবেনিয়া",
            capital="তিরানা",
        ),
        Country(
            timezones=["এশিয়া/ইয়েরেভান"],
            alpha_2_code="AM",
            alpha_3_code="ARM",
            continent="এশিয়া",
            name="আর্মেনিয়া",
            capital="ইয়েরেভান",
        ),
        Country(
            timezones=["আফ্রিকা/লুয়ান্ডা"],
            alpha_2_code="AO",
            alpha_3_code="আগে",
            continent="আফ্রিকা",
            name="অ্যাঙ্গোলা",
            capital="লুয়ান্ডা",
        ),
        Country(
            timezones=[
                "আমেরিকা/আর্জেন্টিনা/বুয়েনস_আয়ার্স",
                "আমেরিকা/আর্জেন্টিনা/কর্ডোবা",
                "আমেরিকা/আর্জেন্টিনা/জুজুয়",
                "আমেরিকা/আর্জেন্টিনা/টুকুমান",
                "আমেরিকা/আর্জেন্টিনা/কাটামার্কা",
                "আমেরিকা/আর্জেন্টিনা/লা_রিওজা",
                "আমেরিকা/আর্জেন্টিনা/সান_জুয়ান",
                "আমেরিকা/আর্জেন্টিনা/মেন্ডোজা",
                "আমেরিকা/আর্জেন্টিনা/রিও_গ্যালেগোস",
                "আমেরিকা/আর্জেন্টিনা/উশুইয়া",
            ],
            alpha_2_code="AR",
            alpha_3_code="ARG",
            continent="দক্ষিণ আমেরিকা",
            name="আর্জেন্টিনা",
            capital="বুয়েনস আইরেস",
        ),
        Country(
            timezones=["ইউরোপ/ভিয়েনা"],
            alpha_2_code="AT",
            alpha_3_code="AUT",
            continent="ইউরোপ",
            name="অস্ট্রিয়া",
            capital="ভিয়েনা",
        ),
        Country(
            timezones=[
                "অস্ট্রেলিয়া/লর্ড_হাউ",
                "অস্ট্রেলিয়া/হোবার্ট",
                "অস্ট্রেলিয়া/কারি",
                "অস্ট্রেলিয়া/মেলবোর্ন",
                "অস্ট্রেলিয়া/সিডনি",
                "অস্ট্রেলিয়া/ব্রোকেন_হিল",
                "অস্ট্রেলিয়া/ব্রিসবেন",
                "অস্ট্রেলিয়া/লিন্ডেম্যান",
                "অস্ট্রেলিয়া/অ্যাডিলেড",
                "অস্ট্রেলিয়া/ডারউইন",
                "অস্ট্রেলিয়া/পার্থ",
            ],
            alpha_2_code="AU",
            alpha_3_code="AUS",
            continent="ওশেনিয়া",
            name="অস্ট্রেলিয়া",
            capital="ক্যানবেরা",
        ),
        Country(
            timezones=["এশিয়া/বাকু"],
            alpha_2_code="AZ",
            alpha_3_code="AZE",
            continent="এশিয়া",
            name="আজারবাইজান",
            capital="বাকু",
        ),
        Country(
            timezones=["আমেরিকা/বার্বাডোস"],
            alpha_2_code="BB",
            alpha_3_code="BRB",
            continent="উত্তর আমেরিকা",
            name="বার্বাডোস",
            capital="ব্রিজটাউন",
        ),
        Country(
            timezones=["এশিয়া/ঢাকা"],
            alpha_2_code="বিডি",
            alpha_3_code="BGD",
            continent="এশিয়া",
            name="বাংলাদেশ",
            capital="ঢাকা",
        ),
        Country(
            timezones=["ইউরোপ/ব্রাসেলস"],
            alpha_2_code="BE",
            alpha_3_code="BEL",
            continent="ইউরোপ",
            name="বেলজিয়াম",
            capital="ব্রাসেলস",
        ),
        Country(
            timezones=["আফ্রিকা/ওগাডুগু"],
            alpha_2_code="BF",
            alpha_3_code="BFA",
            continent="আফ্রিকা",
            name="বুর্কিনা ফাসো",
            capital="ওগাডুগউ",
        ),
        Country(
            timezones=["ইউরোপ/সোফিয়া"],
            alpha_2_code="বিজি",
            alpha_3_code="BGR",
            continent="ইউরোপ",
            name="বুলগেরিয়া",
            capital="সোফিয়া",
        ),
        Country(
            timezones=["এশিয়া/বাহরাইন"],
            alpha_2_code="BH",
            alpha_3_code="BHR",
            continent="এশিয়া",
            name="বাহরাইন",
            capital="মাnameা",
        ),
        Country(
            timezones=["আফ্রিকা/বুজুম্বুরা"],
            alpha_2_code="BI",
            alpha_3_code="BDI",
            continent="আফ্রিকা",
            name="বুরুন্ডি",
            capital="বুজুম্বুরা",
        ),
        Country(
            timezones=["আফ্রিকা/পোর্টো-নোভো"],
            alpha_2_code="BJ",
            alpha_3_code="BEN",
            continent="আফ্রিকা",
            name="বেনিন",
            capital="পোর্টো-নভো",
        ),
        Country(
            timezones=["এশিয়া/ব্রুনাই"],
            alpha_2_code="BN",
            alpha_3_code="BRN",
            continent="এশিয়া",
            name="ব্রুনাই দারুসসালাম",
            capital="বন্দর সেরি বেগাওয়ান",
        ),
        Country(
            timezones=["আমেরিকা/লা_পাজ"],
            alpha_2_code="BO",
            alpha_3_code="BOL",
            continent="দক্ষিণ আমেরিকা",
            name="বলিভিয়া",
            capital="সুক্রে",
        ),
        Country(
            timezones=[
                "আমেরিকা/নরোনহা",
                "আমেরিকা/বেলেম",
                "আমেরিকা/ফর্তালেজা",
                "আমেরিকা/রেসিফ",
                "আমেরিকা/আরাগুয়েনা",
                "আমেরিকা/ম্যাসিও",
                "আমেরিকা/বাহিয়া",
                "আমেরিকা/সাও_পাওলো",
                "আমেরিকা/ক্যাম্পো_গ্রান্ডে",
                "আমেরিকা/কুয়াবা",
                "আমেরিকা/পোর্টো_ভেলহো",
                "আমেরিকা/বোয়া_ভিস্তা",
                "আমেরিকা/মানাস",
                "আমেরিকা/ইরুনেপে",
                "আমেরিকা/রিও_ব্র্যাঙ্কো",
            ],
            alpha_2_code="BR",
            alpha_3_code="BRA",
            continent="দক্ষিণ আমেরিকা",
            name="ব্রাজিল",
            capital="ব্রাসেলস",
        ),
        Country(
            timezones=["আমেরিকা/নাসাউ"],
            alpha_2_code="BS",
            alpha_3_code="BHS",
            continent="উত্তর আমেরিকা",
            name="বাহামাস",
            capital="নাসাউ",
        ),
        Country(
            timezones=["এশিয়া/থিম্পু"],
            alpha_2_code="BT",
            alpha_3_code="BTN",
            continent="এশিয়া",
            name="ভুটান",
            capital="থিম্পু",
        ),
        Country(
            timezones=["আফ্রিকা/গ্যাবোরোন"],
            alpha_2_code="BW",
            alpha_3_code="BWA",
            continent="আফ্রিকা",
            name="বতসোয়ানা",
            capital="গ্যাবরোন",
        ),
        Country(
            timezones=["ইউরোপ/মিনস্ক"],
            alpha_2_code="দ্বারা",
            alpha_3_code="BLR",
            continent="ইউরোপ",
            name="বেলারুশ",
            capital="মিনস্ক",
        ),
        Country(
            timezones=["আমেরিকা/বেলিজ"],
            alpha_2_code="BZ",
            alpha_3_code="BLZ",
            continent="উত্তর আমেরিকা",
            name="বেলিজ",
            capital="বেলমোপান",
        ),
        Country(
            timezones=[
                "আমেরিকা/সেন্ট জনস",
                "আমেরিকা/হ্যালিফ্যাক্স",
                "আমেরিকা/গ্লেস_বে",
                "আমেরিকা/মঙ্কটন",
                "আমেরিকা/গোজ_বে",
                "আমেরিকা/ব্ল্যাঙ্ক-সাবলন",
                "আমেরিকা/মন্ট্রিল",
                "আমেরিকা/টরন্টো",
                "আমেরিকা/নিপিগন",
                "আমেরিকা/থান্ডার_বে",
                "আমেরিকা/পাংনিরতুং",
                "আমেরিকা/ইকালুইট",
                "আমেরিকা/আতিকোকান",
                "আমেরিকা/র‍্যাঙ্কিন_ইনলেট",
                "আমেরিকা/উইনিপেগ",
                "আমেরিকা/বৃষ্টি_নদী",
                "আমেরিকা/কেমব্রিজ_বে",
                "আমেরিকা/রেজিনা",
                "আমেরিকা/সুইফট_কারেন্ট",
                "আমেরিকা/এডমন্টন",
                "আমেরিকা/ইয়েলোনাইফ",
                "আমেরিকা/ইনুভিক",
                "আমেরিকা/ডসন_ক্রিক",
                "আমেরিকা/ভ্যাঙ্কুভার",
                "আমেরিকা/হোয়াইটহরস",
                "আমেরিকা/ডসন",
            ],
            alpha_2_code="CA",
            alpha_3_code="CAN",
            continent="উত্তর আমেরিকা",
            name="কানাডা",
            capital="অটোয়া",
        ),
        Country(
            timezones=["আফ্রিকা/কিনশাসা", "আফ্রিকা/লুবুম্বাশি"],
            alpha_2_code="CD",
            alpha_3_code="COD",
            continent="আফ্রিকা",
            name="কঙ্গো গণতান্ত্রিক প্রজাতন্ত্র",
            capital="কিনশাসা",
        ),
        Country(
            timezones=["আফ্রিকা/ব্রাজাভিল"],
            alpha_2_code="CG",
            alpha_3_code="COG",
            continent="আফ্রিকা",
            name="কঙ্গো প্রজাতন্ত্র",
            capital="ব্রাজাভিল",
        ),
        Country(
            timezones=["আফ্রিকা/আবিজান"],
            alpha_2_code="CI",
            alpha_3_code="CIV",
            continent="আফ্রিকা",
            name="C\xc3\xb4te d'Ivoire",
            capital="ইয়ামুসুক্রো",
        ),
        Country(
            timezones=["আমেরিকা/সান্টিয়াগো", "প্যাসিফিক/ইস্টার"],
            alpha_2_code="CL",
            alpha_3_code="CHL",
            continent="দক্ষিণ আমেরিকা",
            name="চিলি",
            capital="সান্তিয়াগো",
        ),
        Country(
            timezones=["আফ্রিকা/ডুয়ালা"],
            alpha_2_code="CM",
            alpha_3_code="CMR",
            continent="আফ্রিকা",
            name="ক্যামেরুন",
            capital="ইয়াউন্ড",
        ),
        Country(
            timezones=[
                "এশিয়া/সাংহাই",
                "এশিয়া/হারবিন",
                "এশিয়া/চংকিং",
                "এশিয়া/উরুমকি",
                "এশিয়া/কাশগর",
            ],
            alpha_2_code="CN",
            alpha_3_code="CHN",
            continent="এশিয়া",
            name="গণপ্রজাতন্ত্রী চীন",
            capital="বেইজিং",
        ),
        Country(
            timezones=["আমেরিকা/বোগোটা"],
            alpha_2_code="CO",
            alpha_3_code="COL",
            continent="দক্ষিণ আমেরিকা",
            name="কলম্বিয়া",
            capital="বোগোট\xc3\xa1",
        ),
        Country(
            timezones=["আমেরিকা/কোস্টা_রিকা"],
            alpha_2_code="CR",
            alpha_3_code="CRI",
            continent="উত্তর আমেরিকা",
            name="কোস্টারিকা",
            capital="সান জোস\xc3\xa9",
        ),
        Country(
            timezones=["আমেরিকা/হাভানা"],
            alpha_2_code="CU",
            alpha_3_code="CUB",
            continent="উত্তর আমেরিকা",
            name="কিউবা",
            capital="হাভানা",
        ),
        Country(
            timezones=["আটলান্টিক/কেপ_ভার্দে"],
            alpha_2_code="সিভি",
            alpha_3_code="CPV",
            continent="আফ্রিকা",
            name="কেপ ভার্দে",
            capital="প্রাইয়া",
        ),
        Country(
            timezones=["এশিয়া/নিকোসিয়া"],
            alpha_2_code="CY",
            alpha_3_code="CYP",
            continent="এশিয়া",
            name="সাইপ্রাস",
            capital="নিকোসিয়া",
        ),
        Country(
            timezones=["ইউরোপ/প্রাগ"],
            alpha_2_code="CZ",
            alpha_3_code="CZE",
            continent="ইউরোপ",
            name="চেক প্রজাতন্ত্র",
            capital="প্রাগ",
        ),
        Country(
            timezones=["ইউরোপ/বার্লিন"],
            alpha_2_code="DE",
            alpha_3_code="DEU",
            continent="ইউরোপ",
            name="জার্মানি",
            capital="বার্লিন",
        ),
        Country(
            timezones=["আফ্রিকা/জিবুতি"],
            alpha_2_code="ডিজে",
            alpha_3_code="DJI",
            continent="আফ্রিকা",
            name="জিবুতি",
            capital="জিবুতি শহর",
        ),
        Country(
            timezones=["ইউরোপ/কোপেনহেগেন"],
            alpha_2_code="DK",
            alpha_3_code="DNK",
            continent="ইউরোপ",
            name="ডেনমার্ক",
            capital="কোপেনহেগেন",
        ),
        Country(
            timezones=["আমেরিকা/ডোমিনিকা"],
            alpha_2_code="DM",
            alpha_3_code="DMA",
            continent="উত্তর আমেরিকা",
            name="ডোমিনিকা",
            capital="রোজাও",
        ),
        Country(
            timezones=["আমেরিকা/সান্টো_ডোমিঙ্গো"],
            alpha_2_code="করুন",
            alpha_3_code="DOM",
            continent="উত্তর আমেরিকা",
            name="ডোমিনিকান রিপাবলিক",
            capital="সান্তো ডোমিঙ্গো",
        ),
        Country(
            timezones=["আমেরিকা/গুয়াকিল", "প্যাসিফিক/গালাপাগোস"],
            alpha_2_code="EC",
            alpha_3_code="ECU",
            continent="দক্ষিণ আমেরিকা",
            name="ইকুয়েডর",
            capital="কুইটো",
        ),
        Country(
            timezones=["ইউরোপ/টালিন"],
            alpha_2_code="EE",
            alpha_3_code="EST",
            continent="ইউরোপ",
            name="এস্তোনিয়া",
            capital="টালিন",
        ),
        Country(
            timezones=["আফ্রিকা/কায়রো"],
            alpha_2_code="EG",
            alpha_3_code="EGY",
            continent="আফ্রিকা",
            name="মিশর",
            capital="কায়রো",
        ),
        Country(
            timezones=["আফ্রিকা/আসমেরা"],
            alpha_2_code="ER",
            alpha_3_code="ERI",
            continent="আফ্রিকা",
            name="ইরিত্রিয়া",
            capital="আসমারা",
        ),
        Country(
            timezones=["আফ্রিকা/আদিস_আবাবা"],
            alpha_2_code="ET",
            alpha_3_code="ETH",
            continent="আফ্রিকা",
            name="ইথিওপিয়া",
            capital="আদিস আবাবা",
        ),
        Country(
            timezones=["ইউরোপ/হেলসিঙ্কি"],
            alpha_2_code="FI",
            alpha_3_code="FIN",
            continent="ইউরোপ",
            name="ফিনল্যান্ড",
            capital="হেলসিঙ্কি",
        ),
        Country(
            timezones=["প্যাসিফিক/ফিজি"],
            alpha_2_code="FJ",
            alpha_3_code="FJI",
            continent="ওশেনিয়া",
            name="ফিজি",
            capital="সুভা",
        ),
        Country(
            timezones=["ইউরোপ/প্যারিস"],
            alpha_2_code="FR",
            alpha_3_code="FRA",
            continent="ইউরোপ",
            name="ফ্রান্স",
            capital="প্যারিস",
        ),
        Country(
            timezones=["আফ্রিকা/লিব্রেভিল"],
            alpha_2_code="GA",
            alpha_3_code="GAB",
            continent="আফ্রিকা",
            name="গ্যাবন",
            capital="লিব্রেভিল",
        ),
        Country(
            timezones=["এশিয়া/টিবিলিসি"],
            alpha_2_code="GE",
            alpha_3_code="জিও",
            continent="এশিয়া",
            name="জর্জিয়া",
            capital="তিবিলিসি",
        ),
        Country(
            timezones=["আফ্রিকা/আকরা"],
            alpha_2_code="GH",
            alpha_3_code="GHA",
            continent="আফ্রিকা",
            name="ঘানা",
            capital="আকরা",
        ),
        Country(
            timezones=["আফ্রিকা/বানজুল"],
            alpha_2_code="GM",
            alpha_3_code="GMB",
            continent="আফ্রিকা",
            name="গাম্বিয়া",
            capital="বানজুল",
        ),
        Country(
            timezones=["আফ্রিকা/কোনাক্রি"],
            alpha_2_code="GN",
            alpha_3_code="GIN",
            continent="আফ্রিকা",
            name="গিনি",
            capital="কোনাক্রি",
        ),
        Country(
            timezones=["ইউরোপ/এথেন্স"],
            alpha_2_code="GR",
            alpha_3_code="GRC",
            continent="ইউরোপ",
            name="গ্রীস",
            capital="এথেন্স",
        ),
        Country(
            timezones=["আমেরিকা/গুয়েতেমালা"],
            alpha_2_code="GT",
            alpha_3_code="GTM",
            continent="উত্তর আমেরিকা",
            name="গুয়েতেমালা",
            capital="গুয়েতেমালা সিটি",
        ),
        Country(
            timezones=["আমেরিকা/গুয়েতেমালা"],
            alpha_2_code="HT",
            alpha_3_code="HTI",
            continent="উত্তর আমেরিকা",
            name="হাইতি",
            capital="পোর্ট-অ-প্রিন্স",
        ),
        Country(
            timezones=["আফ্রিকা/বিসাউ"],
            alpha_2_code="GW",
            alpha_3_code="GNB",
            continent="আফ্রিকা",
            name="গিনি-বিসাউ",
            capital="বিসাউ",
        ),
        Country(
            timezones=["আমেরিকা/গিয়ানা"],
            alpha_2_code="GY",
            alpha_3_code="লোক",
            continent="দক্ষিণ আমেরিকা",
            name="গিয়ানা",
            capital="জর্জটাউন",
        ),
        Country(
            timezones=["আমেরিকা/টেগুসিগালপা"],
            alpha_2_code="HN",
            alpha_3_code="HND",
            continent="উত্তর আমেরিকা",
            name="হন্ডুরাস",
            capital="টেগুসিগালপা",
        ),
        Country(
            timezones=["ইউরোপ/বুদাপেস্ট"],
            alpha_2_code="HU",
            alpha_3_code="HUN",
            continent="ইউরোপ",
            name="হাঙ্গেরি",
            capital="বুদাপেস্ট",
        ),
        Country(
            timezones=[
                "এশিয়া/জাকার্তা",
                "এশিয়া/পন্টিয়ানাক",
                "এশিয়া/মাকাসার",
                "এশিয়া/জয়াপুরা",
            ],
            alpha_2_code="আইডি",
            alpha_3_code="IDN",
            continent="এশিয়া",
            name="ইন্দোনেশিয়া",
            capital="জাকার্তা",
        ),
        Country(
            timezones=["ইউরোপ/ডাবলিন"],
            alpha_2_code="IE",
            alpha_3_code="IRL",
            continent="ইউরোপ",
            name="আয়ারল্যান্ড প্রজাতন্ত্র",
            capital="ডাবলিন",
        ),
        Country(
            timezones=["এশিয়া/জেরুজালেম"],
            alpha_2_code="IL",
            alpha_3_code="ISR",
            continent="এশিয়া",
            name="ইসরায়েল",
            capital="জেরুজালেম",
        ),
        Country(
            timezones=["এশিয়া/কলকাতা"],
            alpha_2_code="IN",
            alpha_3_code="IND",
            continent="এশিয়া",
            name="ভারত",
            capital="নয়া দিল্লী",
        ),
        Country(
            timezones=["এশিয়া/বাগদাদ"],
            alpha_2_code="IQ",
            alpha_3_code="IRQ",
            continent="এশিয়া",
            name="ইরাক",
            capital="বাগদাদ",
        ),
        Country(
            timezones=["এশিয়া/তেহরান"],
            alpha_2_code="IR",
            alpha_3_code="IRN",
            continent="এশিয়া",
            name="ইরান",
            capital="তেহরান",
        ),
        Country(
            timezones=["আটলান্টিক/রেকজাভিক"],
            alpha_2_code="IS",
            alpha_3_code="ISL",
            continent="ইউরোপ",
            name="আইসল্যান্ড",
            capital="রেকজাভিক",
        ),
        Country(
            timezones=["ইউরোপ/রোম"],
            alpha_2_code="IT",
            alpha_3_code="ITA",
            continent="ইউরোপ",
            name="ইতালি",
            capital="রোম",
        ),
        Country(
            timezones=["আমেরিকা/জ্যামাইকা"],
            alpha_2_code="JM",
            alpha_3_code="JAM",
            continent="উত্তর আমেরিকা",
            name="জ্যামাইকা",
            capital="কিংসটন",
        ),
        Country(
            timezones=["এশিয়া/আম্মান"],
            alpha_2_code="JO",
            alpha_3_code="JOR",
            continent="এশিয়া",
            name="জর্ডান",
            capital="আম্মান",
        ),
        Country(
            timezones=["এশিয়া/টোকিও"],
            alpha_2_code="JP",
            alpha_3_code="JPN",
            continent="এশিয়া",
            name="জাপান",
            capital="টোকিও",
        ),
        Country(
            timezones=["আফ্রিকা/নাইরোবি"],
            alpha_2_code="KE",
            alpha_3_code="KEN",
            continent="আফ্রিকা",
            name="কেনিয়া",
            capital="নাইরোবি",
        ),
        Country(
            timezones=["এশিয়া/বিশকেক"],
            alpha_2_code="কেজি",
            alpha_3_code="KGZ",
            continent="এশিয়া",
            name="কিরগিজস্তান",
            capital="বিশকেক",
        ),
        Country(
            timezones=["প্যাসিফিক/তারাওয়া", "প্যাসিফিক/এন্ডারবেরি", "প্যাসিফিক/কিরিটিমাতি"],
            alpha_2_code="KI",
            alpha_3_code="KIR",
            continent="ওশেনিয়া",
            name="কিরিবাতি",
            capital="তারাওয়া",
        ),
        Country(
            timezones=["এশিয়া/পিয়ংইয়ং"],
            alpha_2_code="KP",
            alpha_3_code="PRK",
            continent="এশিয়া",
            name="উত্তর কোরিয়া",
            capital="পিয়ংইয়ং",
        ),
        Country(
            timezones=["এশিয়া/সিউল"],
            alpha_2_code="KR",
            alpha_3_code="KOR",
            continent="এশিয়া",
            name="দক্ষিণ কোরিয়া",
            capital="সিউল",
        ),
        Country(
            timezones=["এশিয়া/কুয়েত"],
            alpha_2_code="কিলোওয়াট",
            alpha_3_code="KWT",
            continent="এশিয়া",
            name="কুয়েত",
            capital="কুয়েত সিটি",
        ),
        Country(
            timezones=["এশিয়া/বৈরুত"],
            alpha_2_code="LB",
            alpha_3_code="LBN",
            continent="এশিয়া",
            name="লেবানন",
            capital="বৈরুত",
        ),
        Country(
            timezones=["ইউরোপ/ভাদুজ"],
            alpha_2_code="LI",
            alpha_3_code="মিথ্যা",
            continent="ইউরোপ",
            name="লিচেনস্টাইন",
            capital="ভাদুজ",
        ),
        Country(
            timezones=["আফ্রিকা/মনরোভিয়া"],
            alpha_2_code="LR",
            alpha_3_code="LBR",
            continent="আফ্রিকা",
            name="লাইবেরিয়া",
            capital="মনরোভিয়া",
        ),
        Country(
            timezones=["আফ্রিকা/মাসেরু"],
            alpha_2_code="LS",
            alpha_3_code="LSO",
            continent="আফ্রিকা",
            name="লেসোথো",
            capital="মাসেরু",
        ),
        Country(
            timezones=["ইউরোপ/ভিলনিয়াস"],
            alpha_2_code="LT",
            alpha_3_code="LTU",
            continent="ইউরোপ",
            name="লিথুয়ানিয়া",
            capital="ভিলনিয়াস",
        ),
        Country(
            timezones=["ইউরোপ/লাক্সেমবার্গ"],
            alpha_2_code="LU",
            alpha_3_code="LUX",
            continent="ইউরোপ",
            name="লাক্সেমবার্গ",
            capital="লাক্সেমবার্গ সিটি",
        ),
        Country(
            timezones=["ইউরোপ/রিগা"],
            alpha_2_code="LV",
            alpha_3_code="LVA",
            continent="ইউরোপ",
            name="লাটভিয়া",
            capital="রিগা",
        ),
        Country(
            timezones=["আফ্রিকা/ত্রিপোলি"],
            alpha_2_code="LY",
            alpha_3_code="LBY",
            continent="আফ্রিকা",
            name="লিবিয়া",
            capital="ত্রিপোলি",
        ),
        Country(
            timezones=["ভারতীয়/আন্তানানারিভো"],
            alpha_2_code="MG",
            alpha_3_code="MDG",
            continent="আফ্রিকা",
            name="মাদাগাস্কার",
            capital="আন্তানানারিভো",
        ),
        Country(
            timezones=["প্যাসিফিক/মাজুরো", "প্যাসিফিক/কোয়াজালেইন"],
            alpha_2_code="MH",
            alpha_3_code="MHL",
            continent="ওশেনিয়া",
            name="মার্শাল দ্বীপপুঞ্জ",
            capital="মাজুরো",
        ),
        Country(
            timezones=["ইউরোপ/স্কোপজে"],
            alpha_2_code="MK",
            alpha_3_code="MKD",
            continent="ইউরোপ",
            name="ম্যাসিডোনিয়া",
            capital="স্কোপজে",
        ),
        Country(
            timezones=["আফ্রিকা/বামাকো"],
            alpha_2_code="ML",
            alpha_3_code="MLI",
            continent="আফ্রিকা",
            name="মালি",
            capital="বামাকো",
        ),
        Country(
            timezones=["এশিয়া/রেঙ্গুন"],
            alpha_2_code="MM",
            alpha_3_code="MMR",
            continent="এশিয়া",
            name="মিয়ানমার",
            capital="নায়প্যিদা",
        ),
        Country(
            timezones=["এশিয়া/উলানবাতার", "এশিয়া/হোভড", "এশিয়া/চোইবালসান"],
            alpha_2_code="MN",
            alpha_3_code="MNG",
            continent="এশিয়া",
            name="মঙ্গোলিয়া",
            capital="উলানবাতার",
        ),
        Country(
            timezones=["আফ্রিকা/নোয়াকচট"],
            alpha_2_code="MR",
            alpha_3_code="MRT",
            continent="আফ্রিকা",
            name="মৌরিতানিয়া",
            capital="নুয়াকচট",
        ),
        Country(
            timezones=["ইউরোপ/মাল্টা"],
            alpha_2_code="MT",
            alpha_3_code="MLT",
            continent="ইউরোপ",
            name="মাল্টা",
            capital="ভ্যালেটা",
        ),
        Country(
            timezones=["ভারতীয়/মরিশাস"],
            alpha_2_code="MU",
            alpha_3_code="MUS",
            continent="আফ্রিকা",
            name="মরিশাস",
            capital="পোর্ট লুইস",
        ),
        Country(
            timezones=["ভারতীয়/মালদ্বীপ"],
            alpha_2_code="MV",
            alpha_3_code="MDV",
            continent="এশিয়া",
            name="মালদ্বীপ",
            capital="মাল\xc3\xa9",
        ),
        Country(
            timezones=["আফ্রিকা/ব্লান্টিয়ার"],
            alpha_2_code="মেগাওয়াট",
            alpha_3_code="MWI",
            continent="আফ্রিকা",
            name="মালাউই",
            capital="লিলংওয়ে",
        ),
        Country(
            timezones=[
                "আমেরিকা/মেক্সিকো_সিটি",
                "আমেরিকা/কানকুন",
                "আমেরিকা/মেরিডা",
                "আমেরিকা/মন্টেরে",
                "আমেরিকা/মাজাতলান",
                "আমেরিকা/চিহুয়াহুয়া",
                "আমেরিকা/হার্মোসিলো",
                "আমেরিকা/টিজুয়ানা",
            ],
            alpha_2_code="MX",
            alpha_3_code="MEX",
            continent="উত্তর আমেরিকা",
            name="মেক্সিকো",
            capital="মেক্সিকো সিটি",
        ),
        Country(
            timezones=["এশিয়া/কুয়ালা_লামপুর", "এশিয়া/কুচিং"],
            alpha_2_code="আমার",
            alpha_3_code="MYS",
            continent="এশিয়া",
            name="মালয়েশিয়া",
            capital="কুয়ালালামপুর",
        ),
        Country(
            timezones=["আফ্রিকা/মাপুটো"],
            alpha_2_code="MZ",
            alpha_3_code="MOZ",
            continent="আফ্রিকা",
            name="মোজাম্বিক",
            capital="মাপুতো",
        ),
        Country(
            timezones=["আফ্রিকা/উইন্ডহোক"],
            alpha_2_code="NA",
            alpha_3_code="NAM",
            continent="আফ্রিকা",
            name="nameিবিয়া",
            capital="উইন্ডহোক",
        ),
        Country(
            timezones=["আফ্রিকা/নিয়ামে"],
            alpha_2_code="NE",
            alpha_3_code="NER",
            continent="আফ্রিকা",
            name="নাইজার",
            capital="নিয়ামে",
        ),
        Country(
            timezones=["আফ্রিকা/লাগোস"],
            alpha_2_code="NG",
            alpha_3_code="NGA",
            continent="আফ্রিকা",
            name="নাইজেরিয়া",
            capital="আবুজা",
        ),
        Country(
            timezones=["আমেরিকা/মানাগুয়া"],
            alpha_2_code="NI",
            alpha_3_code="NIC",
            continent="উত্তর আমেরিকা",
            name="নিকারাগুয়া",
            capital="মানাগুয়া",
        ),
        Country(
            timezones=["ইউরোপ/আমস্টারডাম"],
            alpha_2_code="NL",
            alpha_3_code="NLD",
            continent="ইউরোপ",
            name="নেদারল্যান্ডের রাজ্য",
            capital="আমস্টারডাম",
        ),
        Country(
            timezones=["ইউরোপ/অসলো"],
            alpha_2_code="না",
            alpha_3_code="NOR",
            continent="ইউরোপ",
            name="নরওয়ে",
            capital="অসলো",
        ),
        Country(
            timezones=["এশিয়া/কাটমান্ডু"],
            alpha_2_code="NP",
            alpha_3_code="NPL",
            continent="এশিয়া",
            name="নেপাল",
            capital="কাঠমান্ডু",
        ),
        Country(
            timezones=["প্যাসিফিক/নাউরু"],
            alpha_2_code="NR",
            alpha_3_code="NRU",
            continent="ওশেনিয়া",
            name="নাউরু",
            capital="ইয়েরেন",
        ),
        Country(
            timezones=["প্যাসিফিক/অকল্যান্ড", "প্যাসিফিক/চ্যাথাম"],
            alpha_2_code="NZ",
            alpha_3_code="NZL",
            continent="ওশেনিয়া",
            name="নিউজিল্যান্ড",
            capital="ওয়েলিংটন",
        ),
        Country(
            timezones=["এশিয়া/মাস্কাট"],
            alpha_2_code="OM",
            alpha_3_code="OMN",
            continent="এশিয়া",
            name="ওমান",
            capital="মাস্কাট",
        ),
        Country(
            timezones=["আমেরিকা/পাnameা"],
            alpha_2_code="PA",
            alpha_3_code="PAN",
            continent="উত্তর আমেরিকা",
            name="পাnameা",
            capital="পাnameা সিটি",
        ),
        Country(
            timezones=["আমেরিকা/লিমা"],
            alpha_2_code="PE",
            alpha_3_code="PER",
            continent="দক্ষিণ আমেরিকা",
            name="পেরু",
            capital="লিমা",
        ),
        Country(
            timezones=["প্যাসিফিক/পোর্ট_মোরেসবি"],
            alpha_2_code="PG",
            alpha_3_code="PNG",
            continent="ওশেনিয়া",
            name="পাপুয়া নিউ গিনি",
            capital="পোর্ট মোরসবি",
        ),
        Country(
            timezones=["এশিয়া/ম্যানিলা"],
            alpha_2_code="PH",
            alpha_3_code="PHL",
            continent="এশিয়া",
            name="ফিলিপাইন",
            capital="ম্যানিলা",
        ),
        Country(
            timezones=["এশিয়া/করাচি"],
            alpha_2_code="PK",
            alpha_3_code="PAK",
            continent="এশিয়া",
            name="পাকিস্তান",
            capital="ইসলামাবাদ",
        ),
        Country(
            timezones=["ইউরোপ/ওয়ারশ"],
            alpha_2_code="PL",
            alpha_3_code="POL",
            continent="ইউরোপ",
            name="পোল্যান্ড",
            capital="ওয়ারশ",
        ),
        Country(
            timezones=["ইউরোপ/লিসবন", "আটলান্টিক/মাদেইরা", "আটলান্টিক/আজোরস"],
            alpha_2_code="PT",
            alpha_3_code="PRT",
            continent="ইউরোপ",
            name="পর্তুগাল",
            capital="লিসবন",
        ),
        Country(
            timezones=["প্যাসিফিক/পালাউ"],
            alpha_2_code="PW",
            alpha_3_code="PLW",
            continent="ওশেনিয়া",
            name="পালাউ",
            capital="এনগেরুলমুদ",
        ),
        Country(
            timezones=["আমেরিকা/আসুনসিয়ন"],
            alpha_2_code="PY",
            alpha_3_code="PRY",
            continent="দক্ষিণ আমেরিকা",
            name="প্যারাগুয়ে",
            capital="আসুন্সি\xc3\xb3n",
        ),
        Country(
            timezones=["এশিয়া/কাতার"],
            alpha_2_code="QA",
            alpha_3_code="QAT",
            continent="এশিয়া",
            name="কাতার",
            capital="দোহা",
        ),
        Country(
            timezones=["ইউরোপ/বুখারেস্ট"],
            alpha_2_code="RO",
            alpha_3_code="ROU",
            continent="ইউরোপ",
            name="রোমানিয়া",
            capital="বুখারেস্ট",
        ),
        Country(
            timezones=[
                "ইউরোপ/ক্যালিনিনগ্রাদ",
                "ইউরোপ/মস্কো",
                "ইউরোপ/ভলগোগ্রাদ",
                "ইউরোপ/সামারা",
                "এশিয়া/ইয়েকাটেরিনবার্গ",
                "এশিয়া/ওমস্ক",
                "এশিয়া/নভোসিবিরস্ক",
                "এশিয়া/ক্রাসনোয়ারস্ক",
                "এশিয়া/ইরকুটস্ক",
                "এশিয়া/ইয়াকুটস্ক",
                "এশিয়া/ভ্লাদিভোস্টক",
                "এশিয়া/সাখালিন",
                "এশিয়া/মাগাদান",
                "এশিয়া/কামচাটকা",
                "এশিয়া/আনাডার",
            ],
            alpha_2_code="RU",
            alpha_3_code="RUS",
            continent="ইউরোপ",
            name="রাশিয়া",
            capital="মস্কো",
        ),
        Country(
            timezones=["আফ্রিকা/কিগালি"],
            alpha_2_code="RW",
            alpha_3_code="RWA",
            continent="আফ্রিকা",
            name="রুয়ান্ডা",
            capital="কিগালি",
        ),
        Country(
            timezones=["এশিয়া/রিয়াদ"],
            alpha_2_code="SA",
            alpha_3_code="SAU",
            continent="এশিয়া",
            name="সৌদি আরব",
            capital="রিয়াদ",
        ),
        Country(
            timezones=["প্যাসিফিক/গুয়াডালকানাল"],
            alpha_2_code="SB",
            alpha_3_code="SLB",
            continent="ওশেনিয়া",
            name="সলোমন দ্বীপপুঞ্জ",
            capital="হোনিয়ারা",
        ),
        Country(
            timezones=["ভারতীয়/মাহে"],
            alpha_2_code="SC",
            alpha_3_code="SYC",
            continent="আফ্রিকা",
            name="সেশেলস",
            capital="ভিক্টোরিয়া",
        ),
        Country(
            timezones=["আফ্রিকা/খার্তুম"],
            alpha_2_code="SD",
            alpha_3_code="SDN",
            continent="আফ্রিকা",
            name="সুদান",
            capital="খার্তুম",
        ),
        Country(
            timezones=["ইউরোপ/স্টকহোম"],
            alpha_2_code="SE",
            alpha_3_code="SWE",
            continent="ইউরোপ",
            name="সুইডেন",
            capital="স্টকহোম",
        ),
        Country(
            timezones=["এশিয়া/সিঙ্গাপুর"],
            alpha_2_code="SG",
            alpha_3_code="SGP",
            continent="এশিয়া",
            name="সিঙ্গাপুর",
            capital="সিঙ্গাপুর",
        ),
        Country(
            timezones=["ইউরোপ/লুব্লজানা"],
            alpha_2_code="SI",
            alpha_3_code="SVN",
            continent="ইউরোপ",
            name="স্লোভেনিয়া",
            capital="লুব্লজানা",
        ),
        Country(
            timezones=["ইউরোপ/ব্র্যাটিস্লাভা"],
            alpha_2_code="SK",
            alpha_3_code="SVK",
            continent="ইউরোপ",
            name="স্লোভাকিয়া",
            capital="ব্রাটিস্লাভা",
        ),
        Country(
            timezones=["আফ্রিকা/ফ্রিটাউন"],
            alpha_2_code="SL",
            alpha_3_code="SLE",
            continent="আফ্রিকা",
            name="সিয়েরা লিওন",
            capital="ফ্রিটাউন",
        ),
        Country(
            timezones=["ইউরোপ/সান_মারিনো"],
            alpha_2_code="SM",
            alpha_3_code="SMR",
            continent="ইউরোপ",
            name="সান মারিনো",
            capital="সান মারিনো",
        ),
        Country(
            timezones=["আফ্রিকা/ডাকার"],
            alpha_2_code="SN",
            alpha_3_code="SEN",
            continent="আফ্রিকা",
            name="সেনেগাল",
            capital="ডাকার",
        ),
        Country(
            timezones=["আফ্রিকা/মোগাদিশু"],
            alpha_2_code="SO",
            alpha_3_code="SOM",
            continent="আফ্রিকা",
            name="সোমালিয়া",
            capital="মোগাদিশু",
        ),
        Country(
            timezones=["আমেরিকা/পারামারিবো"],
            alpha_2_code="SR",
            alpha_3_code="SUR",
            continent="দক্ষিণ আমেরিকা",
            name="সুরিname",
            capital="পারমারিবো",
        ),
        Country(
            timezones=["আফ্রিকা/সাও_টোম"],
            alpha_2_code="ST",
            alpha_3_code="STP",
            continent="আফ্রিকা",
            name="S\xc3\xa3o Tom\xc3\xa9 এবং Pr\xc3\xadncipe",
            capital="S\xc3\xa3o টম\xc3\xa9",
        ),
        Country(
            timezones=["এশিয়া/দামাস্কাস"],
            alpha_2_code="SY",
            alpha_3_code="SYR",
            continent="এশিয়া",
            name="সিরিয়া",
            capital="দামাস্কাস",
        ),
        Country(
            timezones=["আফ্রিকা/লোম"],
            alpha_2_code="TG",
            alpha_3_code="TGO",
            continent="আফ্রিকা",
            name="টোগো",
            capital="Lom\xc3\xa9",
        ),
        Country(
            timezones=["এশিয়া/ব্যাংকক"],
            alpha_2_code="TH",
            alpha_3_code="THA",
            continent="এশিয়া",
            name="থাইল্যান্ড",
            capital="ব্যাংকক",
        ),
        Country(
            timezones=["এশিয়া/দুশানবে"],
            alpha_2_code="TJ",
            alpha_3_code="TJK",
            continent="এশিয়া",
            name="তাজিকিস্তান",
            capital="দুশানবে",
        ),
        Country(
            timezones=["এশিয়া/আশগাবাত"],
            alpha_2_code="TM",
            alpha_3_code="TKM",
            continent="এশিয়া",
            name="তুর্কমেনিস্তান",
            capital="আশগাবাত",
        ),
        Country(
            timezones=["আফ্রিকা/টিউনিস"],
            alpha_2_code="TN",
            alpha_3_code="TUN",
            continent="আফ্রিকা",
            name="তিউনিসিয়া",
            capital="তিউনিস",
        ),
        Country(
            timezones=["প্যাসিফিক/টোঙ্গাটাপু"],
            alpha_2_code="TO",
            alpha_3_code="TON",
            continent="ওশেনিয়া",
            name="টোঙ্গা",
            capital="নুকু\xca\xbbalofa",
        ),
        Country(
            timezones=["ইউরোপ/ইস্তানবুল"],
            alpha_2_code="TR",
            alpha_3_code="TUR",
            continent="এশিয়া",
            name="তুরস্ক",
            capital="আঙ্কারা",
        ),
        Country(
            timezones=["আমেরিকা/পোর্ট_অফ_স্পেন"],
            alpha_2_code="TT",
            alpha_3_code="TTO",
            continent="উত্তর আমেরিকা",
            name="ত্রিনিদাদ ও টোবাগো",
            capital="স্পেন বন্দর",
        ),
        Country(
            timezones=["প্যাসিফিক/ফুনাফুটি"],
            alpha_2_code="টিভি",
            alpha_3_code="TUV",
            continent="ওশেনিয়া",
            name="টুভালু",
            capital="ফুনাফুটি",
        ),
        Country(
            timezones=["আফ্রিকা/দার_এস_সালাম"],
            alpha_2_code="TZ",
            alpha_3_code="TZA",
            continent="আফ্রিকা",
            name="তানজানিয়া",
            capital="ডোডোমা",
        ),
        Country(
            timezones=[
                "ইউরোপ/কিয়েভ",
                "ইউরোপ/উজগোরড",
                "ইউরোপ/জাপোরোজি",
                "ইউরোপ/সিমফেরোপল",
            ],
            alpha_2_code="UA",
            alpha_3_code="UKR",
            continent="ইউরোপ",
            name="ইউক্রেন",
            capital="কিয়েভ",
        ),
        Country(
            timezones=["আফ্রিকা/কাম্পালা"],
            alpha_2_code="UG",
            alpha_3_code="UGA",
            continent="আফ্রিকা",
            name="উগান্ডা",
            capital="কাম্পালা",
        ),
        Country(
            timezones=[
                "আমেরিকা/নিউইয়র্ক",
                "আমেরিকা/ডেট্রয়েট",
                "আমেরিকা/কেনটাকি/লুইসভিল",
                "আমেরিকা/কেনটাকি/মন্টিসেলো",
                "আমেরিকা/ইন্ডিয়ানা/ইন্ডিয়ানাপোলিস",
                "আমেরিকা/ইন্ডিয়ানা/মারেঙ্গো",
                "আমেরিকা/ইন্ডিয়ানা/নক্স",
                "আমেরিকা/ইন্ডিয়ানা/ভেভে",
                "আমেরিকা/শিকাগো",
                "আমেরিকা/ইন্ডিয়ানা/ভিনসেনেস",
                "আমেরিকা/ইন্ডিয়ানা/পিটার্সবার্গ",
                "আমেরিকা/মেনোমিনী",
                "আমেরিকা/উত্তর_ডাকোটা/সেন্টার",
                "আমেরিকা/উত্তর_ডাকোটা/নিউ_সালেম",
                "আমেরিকা/ডেনভার",
                "আমেরিকা/বোইস",
                "আমেরিকা/শিপ্রক",
                "আমেরিকা/ফিনিক্স",
                "আমেরিকা/লস_এঞ্জেলেস",
                "আমেরিকা/অ্যাঙ্কোরেজ",
                "আমেরিকা/জুনেউ",
                "আমেরিকা/ইয়াকুটাত",
                "আমেরিকা/name",
                "আমেরিকা/আডাক",
                "প্যাসিফিক/হনোলুলু",
            ],
            alpha_2_code="মার্কিন যুক্তরাষ্ট্র",
            alpha_3_code="USA",
            continent="উত্তর আমেরিকা",
            name="মার্কিন যুক্তরাষ্ট্র",
            capital="ওয়াশিংটন, ডিসি",
        ),
        Country(
            timezones=["আমেরিকা/মন্টেভিডিও"],
            alpha_2_code="UY",
            alpha_3_code="URY",
            continent="দক্ষিণ আমেরিকা",
            name="উরুগুয়ে",
            capital="মন্টেভিডিও",
        ),
        Country(
            timezones=["এশিয়া/সমরকন্দ", "এশিয়া/তাসখন্দ"],
            alpha_2_code="UZ",
            alpha_3_code="UZB",
            continent="এশিয়া",
            name="উজবেকিস্তান",
            capital="তাসখন্দ",
        ),
        Country(
            timezones=["ইউরোপ/ভ্যাটিকান"],
            alpha_2_code="VA",
            alpha_3_code="ভ্যাট",
            continent="ইউরোপ",
            name="ভ্যাটিকান সিটি",
            capital="ভ্যাটিকান সিটি",
        ),
        Country(
            timezones=["আমেরিকা/কারাকাস"],
            alpha_2_code="VE",
            alpha_3_code="VEN",
            continent="দক্ষিণ আমেরিকা",
            name="ভেনিজুয়েলা",
            capital="কারাকাস",
        ),
        Country(
            timezones=["এশিয়া/সাইগন"],
            alpha_2_code="VN",
            alpha_3_code="VNM",
            continent="এশিয়া",
            name="ভিয়েতname",
            capital="হানয়",
        ),
        Country(
            timezones=["প্যাসিফিক/ইফেট"],
            alpha_2_code="VU",
            alpha_3_code="VUT",
            continent="ওশেনিয়া",
            name="ভানুয়াতু",
            capital="পোর্ট ভিলা",
        ),
        Country(
            timezones=["এশিয়া/এডেন"],
            alpha_2_code="YE",
            alpha_3_code="YEM",
            continent="এশিয়া",
            name="ইয়েমেন",
            capital="সানা",
        ),
        Country(
            timezones=["আফ্রিকা/লুসাকা"],
            alpha_2_code="ZM",
            alpha_3_code="ZMB",
            continent="আফ্রিকা",
            name="জাম্বিয়া",
            capital="লুসাকা",
        ),
        Country(
            timezones=["আফ্রিকা/হারারে"],
            alpha_2_code="ZW",
            alpha_3_code="ZWE",
            continent="আফ্রিকা",
            name="জিম্বাবুয়ে",
            capital="হারারে",
        ),
        Country(
            timezones=["আফ্রিকা/আলজিয়ার্স"],
            alpha_2_code="DZ",
            alpha_3_code="DZA",
            continent="আফ্রিকা",
            name="আলজেরিয়া",
            capital="আলজিয়ার্স",
        ),
        Country(
            timezones=["ইউরোপ/সারাজেভো"],
            alpha_2_code="BA",
            alpha_3_code="BIH",
            continent="ইউরোপ",
            name="বসনিয়া ও হার্জেগোভিনা",
            capital="সারায়েভো",
        ),
        Country(
            timezones=["এশিয়া/ফনম_পেন"],
            alpha_2_code="KH",
            alpha_3_code="KHM",
            continent="এশিয়া",
            name="কম্বোডিয়া",
            capital="নম পেন",
        ),
        Country(
            timezones=["আফ্রিকা/বাঙ্গুই"],
            alpha_2_code="CF",
            alpha_3_code="CAF",
            continent="আফ্রিকা",
            name="মধ্য আফ্রিকান প্রজাতন্ত্র",
            capital="বাঙ্গুই",
        ),
        Country(
            timezones=["আফ্রিকা/এনডজামেনা"],
            alpha_2_code="TD",
            alpha_3_code="TCD",
            continent="আফ্রিকা",
            name="চাদ",
            capital="এন'জামেনা",
        ),
        Country(
            timezones=["ভারতীয়/কোমোরো"],
            alpha_2_code="KM",
            alpha_3_code="COM",
            continent="আফ্রিকা",
            name="কোমোরোস",
            capital="মোরোনি",
        ),
        Country(
            timezones=["ইউরোপ/জাগরেব"],
            alpha_2_code="HR",
            alpha_3_code="HRV",
            continent="ইউরোপ",
            name="ক্রোয়েশিয়া",
            capital="জাগরেব",
        ),
        Country(
            timezones=["এশিয়া/দিলি"],
            alpha_2_code="TL",
            alpha_3_code="TLS",
            continent="এশিয়া",
            name="পূর্ব তিমুর",
            capital="দিলি",
        ),
        Country(
            timezones=["আমেরিকা/এল_সালভাদর"],
            alpha_2_code="SV",
            alpha_3_code="SLV",
            continent="উত্তর আমেরিকা",
            name="এল সালভাদর",
            capital="সান সালভাদর",
        ),
        Country(
            timezones=["আফ্রিকা/মালাবো"],
            alpha_2_code="GQ",
            alpha_3_code="GNQ",
            continent="আফ্রিকা",
            name="নিরক্ষীয় গিনি",
            capital="মালাবো",
        ),
        Country(
            timezones=["আমেরিকা/গ্রেনাডা"],
            alpha_2_code="GD",
            alpha_3_code="GRD",
            continent="উত্তর আমেরিকা",
            name="গ্রেনাডা",
            capital="সেন্ট জর্জস",
        ),
        Country(
            timezones=[
                "এশিয়া/আলমাটি",
                "এশিয়া/কিউজিলর্ডা",
                "এশিয়া/আকতোব",
                "এশিয়া/আকতাউ",
                "এশিয়া/ওরাল",
            ],
            alpha_2_code="KZ",
            alpha_3_code="KAZ",
            continent="এশিয়া",
            name="কাজাখস্তান",
            capital="আস্তানা",
        ),
        Country(
            timezones=["এশিয়া/ভিয়েনতিয়েন"],
            alpha_2_code="LA",
            alpha_3_code="LAO",
            continent="এশিয়া",
            name="লাওস",
            capital="ভিয়েনতিয়েন",
        ),
        Country(
            timezones=["প্যাসিফিক/ট্রুক", "প্যাসিফিক/পোনাপে", "প্যাসিফিক/কোসরা"],
            alpha_2_code="FM",
            alpha_3_code="FSM",
            continent="ওশেনিয়া",
            name="মাইক্রোনেশিয়ার ফেডারেটেড স্টেটস",
            capital="পালকির",
        ),
        Country(
            timezones=["ইউরোপ/চিসিনাউ"],
            alpha_2_code="MD",
            alpha_3_code="MDA",
            continent="ইউরোপ",
            name="মোল্দোভা",
            capital="চি\xc5\x9fin\xc4\x83u",
        ),
        Country(
            timezones=["ইউরোপ/মোনাকো"],
            alpha_2_code="MC",
            alpha_3_code="MCO",
            continent="ইউরোপ",
            name="মোনাকো",
            capital="মোনাকো",
        ),
        Country(
            timezones=["ইউরোপ/পডগোরিকা"],
            alpha_2_code="ME",
            alpha_3_code="MNE",
            continent="ইউরোপ",
            name="মন্টিনিগ্রো",
            capital="পডগোরিকা",
        ),
        Country(
            timezones=["আফ্রিকা/ক্যাসাব্লাঙ্কা"],
            alpha_2_code="MA",
            alpha_3_code="MAR",
            continent="আফ্রিকা",
            name="মরক্কো",
            capital="রাবাত",
        ),
        Country(
            timezones=["আমেরিকা/সেন্ট_কিটস"],
            alpha_2_code="KN",
            alpha_3_code="KNA",
            continent="উত্তর আমেরিকা",
            name="সেন্ট কিটস অ্যান্ড নেভিস",
            capital="ব্যাসেটেরে",
        ),
        Country(
            timezones=["আমেরিকা/সেন্ট_লুসিয়া"],
            alpha_2_code="LC",
            alpha_3_code="LCA",
            continent="উত্তর আমেরিকা",
            name="সেন্ট লুসিয়া",
            capital="ক্যাস্ট্রিজ",
        ),
        Country(
            timezones=["America/St_Vincent"],
            alpha_2_code="ভিসি",
            alpha_3_code="VCT",
            continent="উত্তর আমেরিকা",
            name="সেন্ট ভিনসেন্ট এবং গ্রেনাডাইনস",
            capital="কিংসটাউন",
        ),
        Country(
            timezones=["প্যাসিফিক/অপিয়া"],
            alpha_2_code="WS",
            alpha_3_code="WSM",
            continent="ওশেনিয়া",
            name="সামোয়া",
            capital="আপিয়া",
        ),
        Country(
            timezones=["ইউরোপ/বেলগ্রেড"],
            alpha_2_code="RS",
            alpha_3_code="SRB",
            continent="ইউরোপ",
            name="সার্বিয়া",
            capital="বেলগ্রেড",
        ),
        Country(
            timezones=["আফ্রিকা/জোহানেসবার্গ"],
            alpha_2_code="ZA",
            alpha_3_code="ZAF",
            continent="আফ্রিকা",
            name="দক্ষিণ আফ্রিকা",
            capital="প্রিটোরিয়া",
        ),
        Country(
            timezones=["ইউরোপ/মাদ্রিদ", "আফ্রিকা/সেউটা", "আটলান্টিক/ক্যানারি"],
            alpha_2_code="ES",
            alpha_3_code="ESP",
            continent="ইউরোপ",
            name="স্পেন",
            capital="মাদ্রিদ",
        ),
        Country(
            timezones=["এশিয়া/কলম্বো"],
            alpha_2_code="LK",
            alpha_3_code="LKA",
            continent="এশিয়া",
            name="শ্রীলঙ্কা",
            capital="শ্রী জয়বর্ধনেপুরা কোট্টে",
        ),
        Country(
            timezones=["আফ্রিকা/এমবাবেন"],
            alpha_2_code="SZ",
            alpha_3_code="SWZ",
            continent="আফ্রিকা",
            name="সোয়াজিল্যান্ড",
            capital="এমবাবেন",
        ),
        Country(
            timezones=["ইউরোপ/জুরিখ"],
            alpha_2_code="CH",
            alpha_3_code="CHE",
            continent="ইউরোপ",
            name="সুইজারল্যান্ড",
            capital="বার্ন",
        ),
        Country(
            timezones=["এশিয়া/দুবাই"],
            alpha_2_code="AE",
            alpha_3_code="ARE",
            continent="এশিয়া",
            name="সংযুক্ত আরব আমিরাত",
            capital="আবুধাবি",
        ),
        Country(
            timezones=["ইউরোপ/লন্ডন"],
            alpha_2_code="GB",
            alpha_3_code="GBR",
            continent="ইউরোপ",
            name="যুক্তরাজ্য",
            capital="লন্ডন",
        ),
        Country(
            timezones=["এশিয়া/তাইপেই"],
            alpha_2_code="TW",
            alpha_3_code="TWN",
            continent="এশিয়া",
            name="তাইওয়ান",
            capital="তাইপেই",
        ),
        Country(
            timezones=["এশিয়া/গাজা", "এশিয়া/হেব্রন"],
            alpha_2_code="PS",
            alpha_3_code="PSE",
            continent="এশিয়া",
            name="ফিলিস্তিন",
            capital="রামাল্লা",
        ),
    ]

    def day_of_week(self) -> str:
        day = self.date("%w")
        return self.DAY_NAMES[day]

    def month_name(self) -> str:
        month = self.month()
        return self.MONTH_NAMES[month]



from ..de import Provider as CurrencyProvider


class Provider(CurrencyProvider):
    # source: https://de.wikipedia.org/wiki/Schreibweise_von_Zahlen#Dezimaltrennzeichen_2
    price_formats = ["\N{FIGURE DASH}.##", "%.##", "%#.##", "%##.##", "% ###.##", "%# ###.##"]

    def pricetag(self):
        return "Fr.\N{NO-BREAK SPACE}" + self.numerify(self.random_element(self.price_formats))



from .. import Provider as CompanyProvider


class Provider(CompanyProvider):
    formats = ("{{company_prefix}}{{company_suffix}}",)

    company_prefixes = (
        "品王餐飲",
        "一統企業",
        "品誠",
        "台灣電信",
        "Goagle",
        "一統星巴克",
        "台日積體電路",
        "榮長航空",
        "台灣印無品良",
        "華中航空",
        "台灣人銀行",
        "國中鋼鐵",
        "海鴻精密",
        "台灣鐵高",
        "家宜家居（KIEA）",
        "天上雜誌",
        "台灣力電",
        "碩華電腦",
        "雄豹旅遊",
        "光新三越百貨",
        "台灣軟微",
        "鐵台",
        "一統超商",
        "碁宏",
        "創群光電（奇原美電子）",
        "台灣酒菸",
        "美奧廣告",
        "AYHOO!摩奇",
        "台灣台油",
        "達宏國際電子",
        "華晶國際酒店",
        "秀威影城",
        "王鼎餐飲集團",
        "台灣五星電子",
        "遊戲葡萄數位科技",
        "橋子王生技",
        "大八電視",
        "台灣業糖",
        "都亞緻麗",
        "台灣來自水",
        "麥當當",
        "風微廣場",
        "見遠雜誌",
        "石金堂",
        "邦城文化事業",
        "華中郵政",
        "達友光電",
        "中台信託商業銀行",
        "台北登來喜大飯店",
        "全味食品工業",
        "遠西百貨",
        "旗花（台灣銀）行",
        "冠智科技",
        "丹味企業",
        "發聯科技",
        "台灣雅萊（Y'ORÉAL）",
        "古太可口可樂",
        "榮長海運",
        "達廣電腦",
        "華福大飯店",
        "立三電視",
        "星燦國際旅行社",
        "衣優庫（Nuiqlo）",
        "德汎",
        "台北眾大捷運",
        "共公電視",
        "明陽海運",
        "雄遠建設事業",
        "台灣迪奧汽車",
        "台灣地土銀行",
        "天中電視",
        "月日光半導體",
        "塑台石化",
        "樂可旅遊集團",
        "信永藥品",
        "輝燁企業",
        "興復航空運輸",
        "豐兆國際商業銀行",
        "平太洋崇光百貨",
        "神漢名店百貨",
        "台灣士賓",
        "賓國大飯店",
        "業商週刊",
        "台灣BIM",
        "湖劍山世界",
        "合作庫金商業銀行",
        "台北邦富商業銀行",
        "愛味之",
        "邦富人壽保險",
        "律理法律",
        "心安食品服務（斯摩漢堡）",
        "松黑",
        "台灣生資堂",
        "鮮爭",
        "達台電子",
        "聯燁鋼鐵",
        "華聯電子",
        "瑞輝大藥廠",
        "隆豐大飯店（北台君悅）",
        "資華粧業（生資堂）",
    )

    company_suffixes = ("", "有限公司", "股份有限公司", "資訊有限公司")

    def company_prefix(self) -> str:
        return self.random_element(self.company_prefixes)



from .. import BaseProvider

localized = False


class Provider(BaseProvider):
    """Provider for music-related data."""

    # Music genres
    music_genres = [
        "Rock", "Pop", "Hip Hop", "Jazz", "Blues", "Country", "Classical",
        "Electronic", "R&B", "Soul", "Funk", "Disco", "Reggae", "Punk",
        "Metal", "Alternative", "Indie", "Folk", "Gospel", "Latin",
        "World Music", "Dance", "House", "Techno", "Trance", "Dubstep",
        "Drum and Bass", "Ambient", "Experimental", "Ska", "Grunge",
        "Emo", "Hardcore", "Progressive Rock", "Psychedelic", "Bluegrass",
        "Opera", "Symphony", "Chamber Music", "K-Pop", "J-Pop", "Afrobeat",
        "Bossa Nova", "Flamenco", "Salsa", "Merengue", "Cumbia", "Tango"
    ]

    # Musical instruments
    instruments = [
        # String instruments
        "Guitar", "Electric Guitar", "Bass Guitar", "Acoustic Guitar",
        "Violin", "Viola", "Cello", "Double Bass", "Harp", "Ukulele",
        "Banjo", "Mandolin", "Sitar", "Lute",
        
        # Wind instruments
        "Flute", "Clarinet", "Oboe", "Bassoon", "Saxophone", "Trumpet",
        "Trombone", "French Horn", "Tuba", "Harmonica", "Recorder",
        "Piccolo", "Bagpipes", "Pan Flute",
        
        # Percussion instruments
        "Drums", "Drum Kit", "Snare Drum", "Bass Drum", "Timpani",
        "Xylophone", "Marimba", "Vibraphone", "Cymbals", "Tambourine",
        "Bongos", "Congas", "Djembe", "Tabla", "Gong",
        
        # Keyboard instruments
        "Piano", "Grand Piano", "Electric Piano", "Keyboard", "Organ",
        "Synthesizer", "Accordion", "Harpsichord", "Celesta"
    ]

    # Song title templates
    song_title_templates = [
        "{{word}} {{word_2}}",
        "{{word}} in the {{word_2}}",
        "{{word}} of {{word_2}}",
        "The {{word}}",
        "{{word}} Me",
        "I {{verb}} {{word}}",
        "{{word}} Tonight",
        "{{word}} Forever",
        "{{word}} Dreams",
        "{{word}} Heart",
        "{{word}} Soul",
        "{{word}} Love",
        "{{word}} Blues",
        "{{word}} Song",
        "{{word}} Nights",
        "{{word}} Days",
        "{{word}} Rain",
        "{{word}} Sun",
        "{{word}} Moon",
        "{{word}} Star",
    ]

    # Album name templates
    album_name_templates = [
        "{{word}}",
        "The {{word}}",
        "{{word}} {{word_2}}",
        "{{word}} and {{word_2}}",
        "{{word}}: {{word_2}}",
        "{{word}} Chronicles",
        "{{word}} Sessions",
        "{{word}} Collection",
        "{{word}} Experience",
        "{{word}} Journey",
        "{{word}} Anthology",
        "{{word}} Memories",
        "{{word}} Stories",
        "Greatest {{word}}",
        "Best of {{word}}",
    ]

    # Artist/Band name templates
    artist_name_templates = [
        "{{last_name}}",
        "{{first_name}} {{last_name}}",
        "{{word}} {{word_2}}",
        "The {{word}}s",
        "The {{word}} {{word_2}}s",
        "{{word}} and the {{word_2}}s",
        "{{first_name}} and the {{word}}s",
        "DJ {{last_name}}",
        "MC {{first_name}}",
        "{{word}} {{last_name}}",
        "{{first_name}} {{word}}",
    ]

    # Record labels
    record_labels = [
        "Atlantic Records", "Capitol Records", "Columbia Records",
        "Def Jam Recordings", "Elektra Records", "Epic Records",
        "Interscope Records", "Island Records", "RCA Records",
        "Republic Records", "Universal Music Group", "Warner Music Group",
        "Sony Music", "EMI Records", "Motown Records", "Geffen Records",
        "Virgin Records", "Parlophone", "Polydor Records", "Decca Records",
        "Blue Note Records", "Sub Pop", "4AD", "Merge Records",
        "Matador Records", "XL Recordings", "Domino Recording Company",
        "Rough Trade Records", "Warp Records", "Ninja Tune"
    ]

    # Music formats
    music_formats = [
        "MP3", "WAV", "FLAC", "AAC", "OGG", "WMA", "ALAC", "AIFF",
        "Vinyl", "CD", "Cassette", "Digital Download", "Streaming"
    ]

    # Music streaming platforms
    streaming_platforms = [
        "Spotify", "Apple Music", "YouTube Music", "Amazon Music",
        "Tidal", "Deezer", "Pandora", "SoundCloud", "Bandcamp",
        "Qobuz", "iHeartRadio", "TuneIn"
    ]

    # Concert venues
    concert_venues = [
        "Madison Square Garden", "The O2 Arena", "Wembley Stadium",
        "Red Rocks Amphitheatre", "Hollywood Bowl", "Royal Albert Hall",
        "Carnegie Hall", "Sydney Opera House", "Coachella Valley",
        "Glastonbury Festival", "Lollapalooza", "Bonnaroo",
        "Austin City Limits", "SXSW", "Burning Man"
    ]

    # Music awards
    music_awards = [
        "Grammy Award", "MTV Video Music Award", "American Music Award",
        "Billboard Music Award", "BET Award", "Country Music Award",
        "Latin Grammy", "BRIT Award", "Juno Award", "ARIA Award",
        "Mercury Prize", "Pulitzer Prize for Music"
    ]

    # Musical terms
    musical_terms = [
        "Tempo", "Rhythm", "Melody", "Harmony", "Chord", "Scale",
        "Octave", "Beat", "Measure", "Key", "Pitch", "Tone",
        "Timbre", "Dynamics", "Crescendo", "Diminuendo", "Forte",
        "Piano", "Allegro", "Adagio", "Andante", "Presto"
    ]

    # Song verbs for templates
    song_verbs = [
        "Love", "Need", "Want", "Miss", "Remember", "Forget",
        "Dance", "Sing", "Cry", "Smile", "Dream", "Believe"
    ]

    # Words for song/album titles
    title_words = [
        "Love", "Heart", "Soul", "Dream", "Night", "Day", "Star",
        "Moon", "Sun", "Fire", "Rain", "Storm", "Wind", "Ocean",
        "Mountain", "River", "Sky", "Light", "Dark", "Shadow",
        "Angel", "Devil", "Heaven", "Hell", "Paradise", "Midnight",
        "Dawn", "Dusk", "Summer", "Winter", "Spring", "Fall",
        "Wild", "Free", "Lost", "Found", "Broken", "Beautiful",
        "Sweet", "Bitter", "Golden", "Silver", "Blue", "Red",
        "Black", "White", "Electric", "Acoustic", "Neon", "Crystal"
    ]

    def music_genre(self) -> str:
        """
        Generate a random music genre.
        
        :example: 'Rock'
        """
        return self.random_element(self.music_genres)

    def instrument(self) -> str:
        """
        Generate a random musical instrument.
        
        :example: 'Guitar'
        """
        return self.random_element(self.instruments)

    def song_title(self) -> str:
        """
        Generate a random song title.
        
        :example: 'Dancing in the Moonlight'
        """
        template = self.random_element(self.song_title_templates)
        # Replace placeholders manually (not using generator.parse for custom placeholders)
        result = template
        if "{{word}}" in result:
            result = result.replace("{{word}}", self.random_element(self.title_words))
        if "{{word_2}}" in result:
            result = result.replace("{{word_2}}", self.random_element(self.title_words))
        if "{{verb}}" in result:
            result = result.replace("{{verb}}", self.random_element(self.song_verbs))
        return result

    def album_name(self) -> str:
        """
        Generate a random album name.
        
        :example: 'The Dark Side'
        """
        template = self.random_element(self.album_name_templates)
        # Replace placeholders manually
        result = template
        if "{{word}}" in result:
            result = result.replace("{{word}}", self.random_element(self.title_words))
        if "{{word_2}}" in result:
            result = result.replace("{{word_2}}", self.random_element(self.title_words))
        return result

    def artist_name(self) -> str:
        """
        Generate a random artist name.
        
        :example: 'John Smith'
        """
        template = self.random_element(self.artist_name_templates)
        # First replace person name placeholders using generator
        if "{{first_name}}" in template or "{{last_name}}" in template:
            result = self.generator.parse(template)
        else:
            result = template
        # Then replace word placeholders manually
        if "{{word}}" in result:
            result = result.replace("{{word}}", self.random_element(self.title_words))
        if "{{word_2}}" in result:
            result = result.replace("{{word_2}}", self.random_element(self.title_words))
        return result

    def band_name(self) -> str:
        """
        Generate a random band name.
        
        :example: 'The Rolling Stones'
        """
        # Use templates that are more band-oriented
        band_templates = [
            "The {{word}}s",
            "The {{word}} {{word_2}}s",
            "{{word}} and the {{word_2}}s",
            "{{word}} {{word_2}}",
        ]
        template = self.random_element(band_templates)
        result = template
        if "{{word}}" in result:
            result = result.replace("{{word}}", self.random_element(self.title_words))
        if "{{word_2}}" in result:
            result = result.replace("{{word_2}}", self.random_element(self.title_words))
        return result

    def record_label(self) -> str:
        """
        Generate a random record label name.
        
        :example: 'Atlantic Records'
        """
        return self.random_element(self.record_labels)

    def music_format(self) -> str:
        """
        Generate a random music format.
        
        :example: 'MP3'
        """
        return self.random_element(self.music_formats)

    def streaming_platform(self) -> str:
        """
        Generate a random music streaming platform.
        
        :example: 'Spotify'
        """
        return self.random_element(self.streaming_platforms)

    def concert_venue(self) -> str:
        """
        Generate a random concert venue or festival name.
        
        :example: 'Madison Square Garden'
        """
        return self.random_element(self.concert_venues)

    def music_award(self) -> str:
        """
        Generate a random music award name.
        
        :example: 'Grammy Award'
        """
        return self.random_element(self.music_awards)

    def musical_term(self) -> str:
        """
        Generate a random musical term.
        
        :example: 'Tempo'
        """
        return self.random_element(self.musical_terms)

    def song_duration(self, min_seconds: int = 120, max_seconds: int = 360) -> str:
        """
        Generate a random song duration in MM:SS format.
        
        :param min_seconds: Minimum duration in seconds (default: 120 = 2:00)
        :param max_seconds: Maximum duration in seconds (default: 360 = 6:00)
        :example: '3:45'
        """
        total_seconds = self.random_int(min_seconds, max_seconds)
        minutes = total_seconds // 60
        seconds = total_seconds % 60
        return f"{minutes}:{seconds:02d}"

    def album_year(self, min_year: int = 1950, max_year: int = 2024) -> int:
        """
        Generate a random album release year.
        
        :param min_year: Minimum year (default: 1950)
        :param max_year: Maximum year (default: 2024)
        :example: 1999
        """
        return self.random_int(min_year, max_year)

    def track_number(self, max_tracks: int = 15) -> int:
        """
        Generate a random track number.
        
        :param max_tracks: Maximum number of tracks (default: 15)
        :example: 7
        """
        return self.random_int(1, max_tracks)

    def bpm(self, min_bpm: int = 60, max_bpm: int = 180) -> int:
        """
        Generate a random BPM (Beats Per Minute).
        
        :param min_bpm: Minimum BPM (default: 60)
        :param max_bpm: Maximum BPM (default: 180)
        :example: 120
        """
        return self.random_int(min_bpm, max_bpm)

    def music_key(self) -> str:
        """
        Generate a random musical key.
        
        :example: 'C Major'
        """
        notes = ["C", "C#", "D", "D#", "E", "F", "F#", "G", "G#", "A", "A#", "B"]
        scales = ["Major", "Minor"]
        return f"{self.random_element(notes)} {self.random_element(scales)}"

    def playlist_name(self) -> str:
        """
        Generate a random playlist name.
        
        :example: 'Summer Vibes'
        """
        playlist_templates = [
            "{{word}} Vibes",
            "{{word}} Mix",
            "{{word}} Playlist",
            "{{word}} Hits",
            "Best of {{word}}",
            "{{word}} Classics",
            "{{word}} Favorites",
            "{{word}} Collection",
            "{{word}} {{word_2}}",
            "My {{word}} Playlist",
        ]
        template = self.random_element(playlist_templates)
        result = template
        if "{{word}}" in result:
            result = result.replace("{{word}}", self.random_element(self.title_words))
        if "{{word_2}}" in result:
            result = result.replace("{{word_2}}", self.random_element(self.title_words))
        return result



from .. import Provider as PersonProvider


class Provider(PersonProvider):
    """
    A Faker provider for generating fake Swahili.
    """

    formats = (
        "{{first_name_male}} {{last_name_male}}",
        "{{first_name_male}} {{last_name_male}}",
        "{{first_name_male}} {{last_name_male}}",
        "{{first_name_male}} {{last_name_male}}",
        "{{first_name_male}} {{last_name_male}} {{last_name_male}}",
        "{{first_name_female}} {{last_name_female}}",
        "{{first_name_female}} {{last_name_female}}",
        "{{first_name_female}} {{last_name_female}}",
        "{{first_name_female}} {{last_name_female}}",
        "{{first_name_female}} {{last_name_female}} {{last_name_female}}",
        "{{prefix_male}} {{first_name_male}} {{last_name_male}}",
        "{{prefix_female}} {{first_name_female}} {{last_name_female}}",
        "{{prefix_male}} {{first_name_male}} {{last_name_male}}",
        "{{prefix_female}} {{first_name_female}} {{last_name_female}}",
    )

    # first names sourced from:
    # 1. https://www.behindthename.com/submit/names/gender/masculine/usage/swahili
    # 2. https://github.com/faker-js/faker/blob/next/src/locales/yo_NG/person/male_first_name.ts

    first_names_male = (
        "Abdu",
        "Aijuka",
        "Amri",
        "Andwele",
        "Angalia",
        "Angavu",
        "Anoni",
        "Asani",
        "Asanti",
        "Athumani",
        "Azizi",
        "Bahari",
        "Bale",
        "Balinda",
        "Beshte",
        "Bibuwa",
        "Boma",
        "Cheusi",
        "Chuki",
        "Dai",
        "Daudi",
        "Duma",
        "Dunia",
        "Ëakumbu",
        "Ekundu",
        "Eliakimu",
        "Enzi",
        "Evance",
        "Fahari",
        "Fanaka",
        "Faraja",
        "Hadithi",
        "Hamis",
        "Harambee",
        "Hekima",
        "Isaya",
        "Issack",
        "Ituri",
        "Jalia",
        "Jangwa",
        "Jelani",
        "Jua",
        "Jumaane",
        "Justiniani",
        "Kaombwe",
        "Kashangaki",
        "Kenyangi",
        "Khamani",
        "Khamisi",
        "Kiapo",
        "Kiburi",
        "Kijana",
        "Kijani",
        "Kimbilio",
        "Kinubi",
        "Kipenzi",
        "Kiume",
        "Kondo",
        "Konradi",
        "Kovu",
        "Kurunzi",
        "Kusiima",
        "Makini",
        "Makunga",
        "Makuu",
        "Matunda",
        "Mavuno",
        "Mohamedi",
        "Mulele",
        "Mwezi",
        "Ngamia",
        "Ngeni",
        "Ntimi",
        "Nuhu",
        "Nuriat",
        "Nwabudike",
        "Osogo",
        "Pambe",
        "Pelaji",
        "Popobawa",
        "Pumbaa",
        "Rashidi",
        "Reshoni",
        "Risasi",
        "Rua",
        "Rubani",
        "Ruhiu",
        "Rungo",
        "Sabari",
        "Sadaka",
        "Sadiki",
        "Safari",
        "Samweli",
        "Seif",
        "Shida",
        "Sifa",
        "Siku",
        "Takatifu",
        "Thabiti",
        "Tisa",
        "Tufani",
        "Tukufu",
        "Ushindi",
        "Usiku",
        "Uzima",
        "Wamwema",
        "Yakobo",
        "Yohana",
        "Yohane",
        "Zahur",
        "Zende",
        "Zuba",
        "Zuhri",
        "Zwatie",
    )
    first_names_female = (
        "Abigaili",
        "Adhra",
        "Adia",
        "Adimu",
        "Akumu",
        "Almasi",
        "Amani",
        "Amondi",
        "Anasa",
        "Angalia",
        "Arusi",
        "Asali",
        "Asanti",
        "Asatira",
        "Asmini",
        "Atiena",
        "Bahari",
        "Boma",
        "Busara",
        "Chaniya",
        "Chausiki",
        "Chipukizi",
        "Chuki",
        "Dainess",
        "Dalili",
        "Enzi",
        "Evance",
        "Fahari",
        "Faisa",
        "Fanaka",
        "Faraja",
        "Farhiya",
        "Farijika",
        "Gethera",
        "Goma",
        "Haiba",
        "Halisi",
        "Hanja",
        "Hashiki",
        "Hatima",
        "Hawehindi",
        "Hekima",
        "Hidaya",
        "Hodari",
        "Humaiya",
        "Imany",
        "Imara",
        "Itanya",
        "Jahi",
        "Jana",
        "Jasiri",
        "Jina",
        "Jua",
        "Kaluwa",
        "Kaombwe",
        "Karama",
        "Kaskazi",
        "Kiah",
        "Kibafupia",
        "Kibibi",
        "Kiburi",
        "Kijana",
        "Kimya",
        "Kinaya",
        "Kiojah",
        "Kipenzi",
        "Kipepeo",
        "Kisima",
        "Kiwara",
        "Kuchanua",
        "Kweli",
        "Lailati",
        "Laini",
        "Madaha",
        "Madini",
        "Madoa",
        "Mahali",
        "Maisha",
        "Majani",
        "Makini",
        "Maliza",
        "Marini",
        "Marjani",
        "Matunda",
        "Maua",
        "Misuli",
        "Mkarkara",
        "Mrihani",
        "Muhima",
        "Musila",
        "Mwamini",
        "Mwasaa",
        "Najuma",
        "Naki",
        "Nashipie",
        "Nasra",
        "Nathari",
        "Nayfa",
        "Nelah",
        "Niara",
        "Nigesa",
        "Njozi",
        "Nula",
        "Nyasi",
        "Nyoka",
        "Nyoni",
        "Nyota",
        "Nyuki",
        "Opwonya",
        "Panya",
        "Paskalia",
        "Reshoni",
        "Rua",
        "Sabari",
        "Sadao",
        "Safari",
        "Safiri",
        "Sarabi",
        "Sarafina",
        "Sauti",
        "Serafina",
        "Shani",
        "Shawana",
        "Shida",
        "Sifa",
        "Siku",
        "Skolastika",
        "Sungara",
        "Swala",
        "Tambika",
        "Tamu",
        "Ta-tanisha",
        "Tisa",
        "Tuere",
        "Tufani",
        "Udeera",
        "Ujamaa",
        "Umande",
        "Umoja",
        "Uzima",
        "Waceera",
        "Wamwema",
        "Waridi",
        "Waseme",
        "Yasinta",
        "Zahnya",
        "Zaituni",
        "Zumaridi",
        "Zuwena",
    )

    first_names = first_names_male + first_names_female

    # last names sourced from :
    # 1.https://www.familyeducation.com/baby-names/surname/origin/kenyan
    last_names_male = (
        "Abwao",
        "Adamu",
        "Baharia",
        "Dhadho",
        "Fuli",
        "Hassani",
        "Juma",
        "Kahinu",
        "Kimachu",
        "Kitumaini",
        "Madhubuti",
        "Magombo",
        "Mathenge",
        "Msuya",
        "Naomi",
        "Nazari",
        "Rikke",
        "Sayyid",
        "Simba",
        "Sinema",
        "Wario",
        "Yudas",
        "Abdi",
        "Ali",
        "Akinyi",
        "Anyango",
        "Juma",
        "Kamau",
        "Kibet",
        "Kimani",
        "Maina",
        "Mwangi",
        "Obama",
        "Ochieng",
        "Onyango",
        "Otieno",
        "Mohamed",
        "Hassan",
        "Wafula",
        "Wanjala",
        "Atieno",
        "Kariuki",
        "Kimutai",
        "Kipkorir",
        "Kipkirui",
        "Kipkemei",
        "Kiplagat",
        "Kiprono",
        "Kipsang",
        "Kiptoo",
        "Kipruto",
        "Mumbi",
        "Muthoni",
        "Njeri",
        "Njoroge",
        "Odhiambo",
        "Omondi",
        "Owuor",
        "Wanijiku",
        "Wambui",
        "Abdullahi",
        "Adan",
        "Ahmed",
        "Auma",
        "Barasa",
        "Hussein",
        "Ibrahim",
        "John",
        "Mutai",
        "Omar",
        "Ouma",
        "Waweru",
    )

    # last names are not sex dependant
    last_names_female = last_names_male
    last_names = last_names_male + last_names_female

    prefixes_female = (
        "Mrs.",
        "Ms.",
        "Dr.",
        "Bi.",
        "Mama",
        "Bibi",
        "Madam",
        "Chief",
        "Dkt.",
        "Mheshimiwa",
        "Mwalimu",
        "Mtukufu",
        "Malkia",
        "Mwanamke",
    )

    prefixes_male = (
        "Mr.",
        "Dr.",
        "Bwana",
        "Mzee",
        "Bw.",
        "Dkt.",
        "Mheshimiwa",
        "Mwalimu",
        "Mtukufu",
        "Mfalme",
    )



# Data sources:
# Igbo names: https://en.wikipedia.org/wiki/Igbo_names
# Additional references:
# - Behind the Name (Igbo, Yoruba): https://www.behindthename.com
# - Journal of West African Languages (Hausa naming practices, 2016)
from randum.providers.person import Provider as PersonProvider


class Provider(PersonProvider):
    # Male first names
    first_names_male = [
        "Chinedu",
        "Obinna",
        "Ifeanyi",
        "Emeka",
        "Uche",
        "Chukwudi",
        "Nnamdi",
        "Ikenna",
        "Ekene",
        "Chibuzo",
        "Ebuka",
        "Nonso",
        "Chukwuemeka",
        "Somtochukwu",
        "Uchenna",
        "Ifechukwu",
        "Chigozie",
        "Okechukwu",
        "Kelechi",
        "Chijioke",
    ]

    # Female first names
    first_names_female = [
        "Adaeze",
        "Chiamaka",
        "Oluchi",
        "Ngozi",
        "Amarachi",
        "Ifunanya",
        "Chinelo",
        "Ogechi",
        "Nneka",
        "Obianuju",
        "Ujunwa",
        "Ifeoma",
        "Chidimma",
        "Nkiruka",
        "Onyinye",
        "Chizoba",
        "Chinyere",
        "Kosisochukwu",
        "Ozioma",
        "Somadina",
    ]

    # Combined list
    first_names = first_names_male + first_names_female

    # Prefixes
    prefixes_male = ["Mr.", "Chief", "Dr.", "Engr.", "Prof."]
    prefixes_female = ["Mrs.", "Miss", "Dr.", "Prof.", "Lady"]

    prefixes = prefixes_male + prefixes_female

    # Last names
    last_names = [
        "Okafor",
        "Eze",
        "Obi",
        "Nwosu",
        "Okeke",
        "Nwachukwu",
        "Onoh",
        "Ogbuehi",
        "Iwu",
        "Chukwu",
        "Onwuka",
        "Anyanwu",
        "Udeh",
        "Ihejirika",
        "Madu",
        "Njoku",
        "Ezeugo",
        "Ojukwu",
        "Iroha",
        "Okoro",
    ]



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

INSTALL_REQUIRES = [
    'numpy',
    'pandas',
]

setuptools.setup(
    name="randum",
    version="1.0.9",
    author="Raja CSP Raman",
    author_email="raja.csp@gmail.com",
    description="Randum - Random Universal Data Generator for Python",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/kactlabs/randum",
    packages=setuptools.find_packages(exclude=['sampleui', 'sampleui.*', 'tact-random', 'tests']),
    package_data={
        "randum": ["py.typed", "proxy.pyi"],
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Testing",
    ],
    install_requires=INSTALL_REQUIRES,
    python_requires='>=3.10',
    zip_safe=False
)


from typing import Dict

from .. import Provider as LoremProvider


class Provider(LoremProvider):
    """Implement lorem provider for ``da_DK`` locale.   # NOQA"""

    word_list = (
        "område",
        "verden",
        "nødvendig",
        "ligge",
        "magt",
        "drøm",
        "midt",
        "indeholde",
        "plads",
        "viden",
        "etage",
        "forstå",
        "social",
        "hvornår",
        "andre",
        "vente",
        "bære",
        "bank",
        "station",
        "budget",
        "hjerte",
        "politisk",
        "ret",
        "fod",
        "åben",
        "sammenligne",
        "national",
        "offer",
        "hver",
        "økonomi",
        "morgen",
        "masse",
        "bestemme",
        "race",
        "nogen",
        "forekomme",
        "at",
        "især",
        "kraft",
        "andet",
        "følelse",
        "bred",
        "problem",
        "hospital",
        "tusind",
        "TV",
        "bold",
        "vælge",
        "medicinsk",
        "dårligst",
        "ja",
        "miljø",
        "forlig",
        "netværk",
        "beskrive",
        "beløb",
        "publikum",
        "scene",
        "tanke",
        "form",
        "officer",
        "cykle",
        "celle",
        "løb",
        "passere",
        "spise",
        "efterår",
        "spekulerer",
        "luft",
        "medier",
        "kant",
        "tre",
        "rækkevidde",
        "møde",
        "resultat",
        "aftensmad",
        "uge",
        "overveje",
        "se",
        "ur",
        "forbrydelse",
        "os",
        "television",
        "krig",
        "videnskab",
        "eksempel",
        "stemme",
        "give",
        "forfatter",
        "hellere",
        "behandling",
        "senere",
        "syv",
        "par",
        "hundrede",
        "hud",
        "enkelt",
        "liste",
        "aften",
        "ud",
        "altid",
        "tryk",
        "effekt",
        "ting",
        "sager",
        "rød",
        "så",
        "hel",
        "vil",
        "have",
        "leder",
        "inde",
        "fordel",
        "taske",
        "aldrig",
        "forskellige",
        "artikel",
        "grine",
        "forklare",
        "jeg",
        "minut",
        "være",
        "eksisterer",
        "forkert",
        "rig",
        "dække",
        "konference",
        "sikker",
        "ejendom",
        "udmelding",
        "plukke",
        "blive",
        "ekspert",
        "hele",
        "vejen",
        "igennem",
        "år",
        "strøm",
        "store",
        "nå",
        "hende",
        "købe",
        "tegne",
        "fattige",
        "kort",
        "rolle",
        "sandsynligvis",
        "der",
        "placere",
        "familie",
        "forskning",
        "dag",
        "telefon",
        "kan",
        "mund",
        "finansiel",
        "evne",
        "design",
        "politik",
        "medlem",
        "anden",
        "lave",
        "læge",
        "skulle",
        "gerne",
        "myndighed",
        "dyrke",
        "sende",
        "kilde",
        "forbi",
        "arbejde",
        "århundrede",
        "dårligt",
        "interesse",
        "vest",
        "lade",
        "jeres",
        "vindue",
        "bestemte",
        "spørge",
        "sige",
        "dette",
        "operation",
        "lille",
        "miljømæssigt",
        "genkende",
        "tilbud",
        "ven",
        "fysisk",
        "nu",
        "svare",
        "hun",
        "ske",
        "syd",
        "fuld",
        "trods",
        "administration",
        "ny",
        "endelig",
        "fremstille",
        "besked",
        "figur",
        "skilt",
        "trin",
        "information",
        "forholde",
        "ned",
        "faktisk",
        "direkte",
        "succes",
        "tjene",
        "debat",
        "varme",
        "barn",
        "niveau",
        "fyr",
        "træ",
        "eftermiddagen",
        "karakter",
        "forlade",
        "sprog",
        "godt",
        "ind",
        "problemer",
        "underviser",
        "stor",
        "ryste",
        "bestyrelse",
        "gå",
        "central",
        "synge",
        "ord",
        "oplade",
        "datter",
        "adresse",
        "hed",
        "seng",
        "rapport",
        "over",
        "penge",
        "alder",
        "tendens",
        "køkken",
        "arbejder",
        "tilstand",
        "side",
        "bekymre",
        "blod",
        "vigtigste",
        "bedst",
        "sang",
        "imidlertid",
        "nævne",
        "tab",
        "hit",
        "vellykket",
        "virkelig",
        "tage",
        "smerte",
        "professor",
        "mørk",
        "vind",
        "årti",
        "hotel",
        "projekt",
        "traditionel",
        "indvirkning",
        "kollektion",
        "seksuel",
        "pris",
        "skulder",
        "rejse",
        "finde",
        "interview",
        "ifølge",
        "grad",
        "medarbejder",
        "trussel",
        "sommer",
        "stå",
        "hvorfor",
        "pæn",
        "individuel",
        "avis",
        "industri",
        "nat",
        "alle",
        "bruge",
        "handling",
        "vej",
        "hård",
        "brev",
        "olie",
        "ved",
        "påvirke",
        "parat",
        "stærk",
        "vigtig",
        "ressource",
        "værdi",
        "påstand",
        "struktur",
        "virkelighed",
        "disse",
        "komme",
        "data",
        "position",
        "glemme",
        "vægt",
        "af",
        "mål",
        "varsel",
        "prøve",
        "jord",
        "død",
        "blå",
        "strategi",
        "vend",
        "tilbage",
        "læs",
        "start",
        "bedre",
        "vise",
        "selvom",
        "konto",
        "på",
        "måle",
        "kvalitet",
        "nord",
        "vestlig",
        "skyde",
        "liv",
        "køre",
        "sandhed",
        "kunstner",
        "jo",
        "da",
        "formue",
        "bjørn",
        "historiker",
        "du",
        "titel",
        "udenlandsk",
        "kontanter",
        "korn",
        "heller",
        "ikke",
        "overlevelse",
        "beskytte",
        "baseball",
        "før",
        "forhandle",
        "afhængig",
        "fase",
        "genetisk",
        "stille",
        "fugl",
        "grøntsag",
        "tillid",
        "episode",
        "kunstnerisk",
        "markedsføring",
        "perfekt",
        "afspejle",
        "emne",
        "jet",
        "synlig",
        "ugentlig",
        "undersøgelse",
        "tank",
        "enhed",
        "gensidig",
        "psykolog",
        "fru",
        "øjeblikket",
        "indlysende",
        "årsag",
        "tilstedeværelse",
        "parkering",
        "forår",
        "tå",
        "muskel",
        "fange",
        "frokost",
        "forpligtelse",
        "spænding",
        "tilhører",
        "gentleman",
        "mig",
        "jury",
        "eventuelt",
        "gård",
        "alsidig",
        "passager",
        "øjeblik",
        "jæger",
        "vane",
        "erkende",
        "erhverve",
        "livsstil",
        "respons",
        "landdistrikter",
        "fantasi",
        "afgørende",
        "langt",
        "fond",
        "insistere",
        "parkere",
        "opnå",
        "fløde",
        "forskel",
        "væsentligt",
        "lappe",
        "morder",
        "længde",
        "poesi",
        "udbredt",
        "ungdom",
        "fjerde",
        "bevæbnet",
        "mirakel",
        "musiker",
        "bind",
        "punkt",
        "frihed",
        "rør",
        "genopretning",
        "forhandler",
        "kun",
        "ben",
        "klinge",
        "nød",
        "tænker",
        "græsplæne",
        "lag",
        "sko",
        "røg",
        "blandt",
        "karriere",
        "angst",
        "dimension",
        "vital",
        "kerne",
        "gul",
        "tælle",
        "forventer",
        "klinik",
        "opbevaring",
        "relevant",
        "måske",
        "meget",
        "egen",
        "chip",
        "trykke",
        "stil",
        "sofistikeret",
        "begrænsning",
        "resterende",
        "pulver",
        "slag",
        "fiktion",
        "aggressiv",
        "anholdelse",
        "syre",
        "glip",
        "afslut",
        "igangværende",
        "afvige",
        "forestille",
        "inflation",
        "regnet",
        "te",
        "sværge",
        "afdeling",
        "DNA",
        "tåre",
        "skib",
        "frembringe",
        "ivrige",
        "tilføjelse",
        "boliger",
        "bombe",
        "helikopter",
        "tag",
        "negativ",
        "regn",
        "dokument",
        "omdømme",
        "sikkert",
        "peber",
        "retfærdig",
        "skygge",
        "type",
        "distrikt",
        "betaling",
        "kontrast",
        "opdage",
        "signal",
        "gnide",
        "svært",
        "uanset",
        "sikkerhed",
        "ovn",
        "major",
        "butik",
        "forsigtigt",
        "flygtning",
        "korrekt",
        "bro",
        "men",
        "kunst",
        "religion",
        "forsøg",
        "kost",
        "kunne",
        "levende",
        "gevinst",
        "kolesterol",
        "sovs",
        "bag",
        "i",
        "billede",
        "desuden",
        "modtage",
        "udgave",
        "hal",
        "skelne",
        "anerkende",
        "bygge",
        "nummer",
        "distribuere",
        "væk",
        "fortælle",
        "mysterium",
        "siden",
        "samling",
        "gen",
        "stof",
        "global",
        "stjæle",
        "funktion",
        "præsidentvalg",
        "respekt",
        "løg",
        "beundre",
        "sælge",
        "mangfoldighed",
        "vidner",
        "fejl",
        "domfældelse",
        "teenager",
        "solid",
        "fødselsdag",
        "som",
        "formand",
        "konkurrence",
        "er",
        "indsigt",
        "nærheden",
        "betyde",
        "annonce",
        "dem",
        "skære",
        "reaktion",
        "romantisk",
        "smag",
        "udgør",
        "lethed",
        "misbrug",
        "sukker",
        "støj",
        "senat",
        "syg",
        "forvirring",
        "formål",
        "trick",
        "hul",
        "klaver",
        "operere",
        "grave",
        "gætte",
        "regime",
        "model",
        "sommetider",
        "politimand",
        "nødsituation",
        "rigtigt",
        "træt",
        "laver",
        "mad",
        "investere",
        "reb",
        "ofte",
        "restaurant",
        "ekstraordinær",
        "fortælling",
        "angreb",
        "størrelse",
        "stjerne",
        "overraskende",
        "elementære",
        "kommunikere",
        "top",
        "til",
        "fødsel",
        "spiseskefuld",
        "konventionelle",
        "køretøj",
        "film",
        "gear",
        "kul",
        "væg",
        "køn",
        "voldsom",
        "vin",
        "værdifuld",
        "forlægger",
        "session",
        "fabrikant",
        "arkitekt",
        "direktør",
        "begge",
        "ødelæggelse",
        "permanent",
        "kristen",
        "klatre",
        "økonom",
        "sats",
        "kæledyr",
        "særlig",
        "metode",
        "tro",
        "tid",
        "konsensus",
        "spids",
        "kategori",
        "forstyrre",
        "terrorist",
        "klare",
        "kat",
        "ønske",
        "tur",
        "skønhed",
        "knap",
        "print",
        "mulighed",
        "rette",
        "høring",
        "levested",
        "bebrejde",
        "øverst",
        "underskud",
        "veje",
        "virksomhed",
        "helt",
        "implementere",
        "produktion",
        "sol",
        "stand",
        "plan",
        "omfavne",
        "batteri",
        "sind",
        "håndbevægelse",
        "husstand",
        "lastbil",
        "begreb",
        "udseende",
        "dræbe",
        "sig",
        "selv",
        "hjælpe",
        "bevise",
        "universel",
        "tekst",
        "uafhængighed",
        "snart",
        "nødvendigvis",
        "sektor",
        "alkohol",
        "ansvarlig",
        "besøg",
        "ly",
        "kvarter",
        "smuds",
        "bidrag",
        "kamp",
        "ankomme",
        "fodbold",
        "spejl",
        "ventilator",
        "skæbne",
        "majs",
        "kræft",
        "spore",
        "legeme",
        "udvælgelse",
        "uddanne",
        "fisk",
        "diagram",
        "stående",
        "massiv",
        "byrde",
        "tilladelse",
        "samme",
        "måler",
        "vælg",
        "person",
        "tilstrækkelig",
        "vedtage",
        "instruktion",
        "musikalsk",
        "bevare",
        "kop",
        "gentage",
        "skrivebord",
        "sjæl",
        "nyttig",
        "fuldt",
        "nærme",
        "overbevise",
        "psykologi",
        "detaljeret",
        "dom",
        "kyst",
        "profil",
        "finansiere",
        "tale",
        "repræsentant",
        "reagere",
        "tegning",
        "mandskab",
        "sekvens",
        "konsulent",
        "formode",
        "skov",
        "skjule",
        "lunge",
        "ankomst",
        "hjemløs",
        "kirke",
        "spændende",
        "guld",
        "time",
        "alligevel",
        "flytte",
        "begavet",
        "brug",
        "koncentration",
        "desperat",
        "væsen",
        "radio",
        "skrig",
        "million",
        "objektiv",
        "nederlag",
        "nederste",
        "holde",
        "senior",
        "matematik",
        "support",
        "rose",
        "pund",
        "hegn",
        "medlemskab",
        "tilmeld",
        "gyldige",
        "forsvar",
        "brun",
        "kæmpe",
        "privat",
        "investering",
        "fejre",
        "advarsel",
        "foreslå",
        "overrasket",
        "mord",
        "garanti",
        "berømthed",
        "frugt",
        "match",
        "alene",
        "tættere",
        "søg",
        "flaske",
        "kriterier",
        "offentlig",
        "centrum",
        "argument",
        "stat",
        "formel",
        "opgave",
        "teknologi",
        "magtfulde",
        "sammenhæng",
        "søge",
        "chef",
        "villig",
        "bekymring",
        "uddannelse",
        "ville",
        "overse",
        "flad",
        "højttaler",
        "forsvinde",
        "lige",
        "forbyde",
        "forbedre",
        "besøgende",
        "lancering",
        "baggrund",
        "pie",
        "lugt",
        "klinisk",
        "udvej",
        "alternativ",
        "afgrøde",
        "øge",
        "dele",
        "indsats",
        "vært",
        "betyder",
        "find",
        "immigrant",
        "lænke",
        "konstant",
        "strategisk",
        "stipendium",
        "skuldertræk",
        "rådgiver",
        "bage",
        "udbyder",
        "løbet",
        "enorm",
        "binde",
        "omsorg",
        "flyve",
        "tung",
        "indkomst",
        "let",
        "bevægelse",
        "opstå",
        "bruser",
        "hen",
        "imod",
        "fylde",
        "mekanisme",
        "tæt",
        "nylig",
        "pensionering",
        "procedure",
        "generelt",
        "henvise",
        "oversætte",
        "tildele",
        "indpakning",
        "medhjælper",
        "næste",
        "håndværk",
        "dybt",
        "specialist",
        "strand",
        "fundament",
        "mejse",
        "overvinde",
        "plante",
        "hej",
        "initial",
        "forhandling",
        "hals",
        "måne",
        "støvle",
        "kongres",
        "forberedelse",
        "minde",
        "opmærksomhed",
        "afsnit",
        "kunde",
        "undskyld",
        "afstand",
        "din",
        "passe",
        "hus",
        "odds",
        "nogle",
        "udvikling",
        "skandale",
        "med",
        "kok",
        "tårn",
        "invitere",
        "skade",
        "konflikt",
        "fordi",
        "guvernør",
        "også",
        "rolige",
        "natur",
        "hvordan",
        "venlig",
        "ledsage",
        "borgmester",
        "via",
        "stolt",
        "gammel",
        "erstatte",
        "lejlighed",
        "kritisk",
        "forudsige",
        "fed",
        "attribut",
        "vagt",
        "vi",
        "forurening",
        "nation",
        "transportør",
        "søn",
        "de",
        "umulig",
        "hør",
        "opskrift",
        "underholdning",
        "brændstof",
        "live",
        "univers",
        "glide",
        "foreslog",
        "indre",
        "sne",
        "krænkelse",
        "sky",
        "masser",
        "provins",
        "gal",
        "institution",
        "henviser",
        "moderne",
        "initiativ",
        "republikansk",
        "begravelse",
        "urban",
        "begrænset",
        "sent",
        "flyselskab",
        "kage",
        "bekostning",
        "album",
        "lyd",
        "rykke",
        "følge",
        "mursten",
        "super",
        "snor",
        "høj",
        "kaffe",
        "vågne",
        "leje",
        "universitetsområde",
        "bånd",
        "defensiv",
        "had",
        "udvidelse",
        "mere",
        "facilitet",
        "variere",
        "våben",
        "styrke",
        "junior",
        "faret",
        "vild",
        "hemmelighed",
        "stirre",
        "efter",
        "tom",
        "eliminere",
        "personale",
        "version",
        "bogstaveligt",
        "talt",
        "sædvanlig",
        "adgang",
        "observation",
        "opførsel",
        "fiasko",
        "psykologisk",
        "fænomen",
        "deltage",
        "informere",
        "indtægter",
        "beslutte",
        "sjovt",
        "høre",
        "under",
        "synes",
        "råd",
        "reduktion",
        "japansk",
        "overalt",
        "programmmere",
        "brygge",
    )

    parts_of_speech: Dict[str, tuple] = {}
